
# FMC OpenAPI

**fmc_openapi** is a Python package that simplifies interaction with Cisco Firepower Management Center (FMC) APIs. It dynamically parses the OpenAPI (Swagger) specification to discover available endpoints and interact with them using the `operationId`.

To identify which operations are supported, you can refer to the Operation ID table at the bottom of this `README` file.

---

## 🚀 Features

- 🔍 Parses the Swagger file to discover endpoints
- 💡 Calls API operations by operationId
- 🔐 Session handling (login/logout)
- 🧰 Simplifies complex API interactions
- ⚠️ Error handling built-in
- 🏢 SCC/CDO Token-Based Authentication
- 🔄 Automatic pagination handling (manual pagination is also possible)
- 📦 Bulk operations
- 📄 All endpoints defined in the Swagger spec

---

## 📦 Installation

```bash
pip install fmc_openapi
```

Import API client

```python
from fmc_openapi import FMCOpenAPIClient
```

---

## 🧑‍💻 Usage Example

### Connecting to FMC (username/password)

```python
from fmc_openapi import FMCOpenAPIClient

with FMCOpenAPIClient(
    hostname="fmc.example.com",
    username="your_username",
    password="your_password",
    verify=False
) as fmc:
    domains = fmc.operation("getAllDomain")
```

### Connecting to SCC (token-based)

```python
from fmc_openapi import FMCOpenAPIClient

with FMCOpenAPIClient(
    hostname="scc.example.com",
    token="your_token_here",
    verify=False
) as fmc:
    domains = fmc.operation("getAllDomain")
```

---

### Get all access policy rules

```python
import jmespath

with FMCOpenAPIClient(
    hostname="fmc.example.com",
    username="your_username",
    password="your_password",
    verify=False
) as fmc:
    # Get domain UUID
    domains = fmc.operation("getAllDomain")
    domain_uuid = jmespath.search("items[?name=='my-domain'].uuid | [0]", domains)

    # Get ACP UUID
    acp_response = fmc.operation("getAllAccessPolicy", domainUUID=domain_uuid)
    acp_uuid = jmespath.search("items[?name=='my-policy'].uuid | [0]", acp_response)

    # Get all access policy rules (with automatic pagination)
    rules = fmc.operation(
        "getAllAccessRule", 
        limit=1000, 
        domainUUID=domain_uuid, 
        containerUUID=acp_uuid, 
        expanded=True
    )
```

---

### Manual Pagination

```python
rules = fmc.operation(
    "getAllAccessRule",
    limit=1000,
    domainUUID=domain_uuid,
    containerUUID=acp_uuid,
    expanded=True,
    manual_pagination=True
)
```

---

### Creating Objects

```python
payload = {
    "name": "obj-192.168.1.0",
    "type": "Network",
    "value": "192.168.1.0/24",
}

fmc.operation("createMultipleNetworkObject", payload=payload, domainUUID=domain_uuid)
```

---

### Bulk Operations

```python
response = fmc.operation(
    "getHitCount", 
    limit=1000, 
    domainUUID=domain_uuid, 
    containerUUID=ac_uuid_selected, 
    filter=f"deviceId:{device_uuid}", 
    expanded=True,
    bulk=True
)
```

---

## 🧪 Running Tests

Tests are written using `pytest`.

To run tests:

```bash
poetry run pytest
```

Or activate the environment first:

```bash
poetry shell
pytest
```

---

## 🛠 Project Structure

```
fmc_openapi/
├── __init__.py           # Imports FMCOpenAPIClient
├── client.py             # Main client class
├── swagger.py            # Swagger parser
├── utils.py              # Logging and request helpers
tests/
├── test_swagger.py       # Tests for Swagger JSON fetching and operation extraction
├── test_operation.py     # Tests for executing API operations using operationId
├── test_auth.py          # Tests for authentication: login and logout
├── test_client.py        # General client behavior and utility method tests
```

---

## 📄 License

GNU GPL v3 License. See `LICENSE` for details.

---

## 🤝 Contributing

Pull requests are welcome! If you plan to add new features, open an issue first to discuss it.

1. Fork the project
2. Create your feature branch
3. Commit your changes
4. Push to the branch
5. Open a pull request

---

## ✉️ Contact

Questions? Ideas? [Open an issue](https://github.com/isrferna/fmc_openapi/issues) or drop a message.

---

## 💡 Operation ID table

An operationId is a unique string defined in the OpenAPI (Swagger) spec for each HTTP operation (GET, POST, etc.) on an endpoint. It's like a function name for the API — a friendly, readable alias that maps to the combination of:

- HTTP method (GET, POST, PUT, DELETE)
- URL path (`/api/fmc_config/v1/domain/{domainUUID}/object/networkobjects`)

The table below was created based on an FMC version 7.6.

| operationId                                    | method | url                                                                                                                                                  |
|------------------------------------------------|--------|------------------------------------------------------------------------------------------------------------------------------------------------------|
| getAllActiveSession                            | GET    | /api/fmc_config/v1/domain/{domainUUID}/analysis/activesessions                                                                                       |
| deleteMultipleActiveSession                    | DELETE | /api/fmc_config/v1/domain/{domainUUID}/analysis/activesessions                                                                                       |
| getAllIdentifiedUser                           | GET    | /api/fmc_config/v1/domain/{domainUUID}/analysis/identifiedusers                                                                                      |
| deleteMultipleIdentifiedUser                   | DELETE | /api/fmc_config/v1/domain/{domainUUID}/analysis/identifiedusers                                                                                      |
| getAllUserActivity                             | GET    | /api/fmc_config/v1/domain/{domainUUID}/analysis/useractivity                                                                                         |
| deleteMultipleUserActivity                     | DELETE | /api/fmc_config/v1/domain/{domainUUID}/analysis/useractivity                                                                                         |
| getAllPolicyAssignment                         | GET    | /api/fmc_config/v1/domain/{domainUUID}/assignment/policyassignments                                                                                  |
| createPolicyAssignment                         | POST   | /api/fmc_config/v1/domain/{domainUUID}/assignment/policyassignments                                                                                  |
| getPolicyAssignment                            | GET    | /api/fmc_config/v1/domain/{domainUUID}/assignment/policyassignments/{objectId}                                                                       |
| updatePolicyAssignment                         | PUT    | /api/fmc_config/v1/domain/{domainUUID}/assignment/policyassignments/{objectId}                                                                       |
| getDownloadBackup                              | GET    | /api/fmc_config/v1/domain/{domainUUID}/backup/downloadbackup/{targetId}                                                                              |
| getAllBackupFile                               | GET    | /api/fmc_config/v1/domain/{domainUUID}/backup/files                                                                                                  |
| getBackupFile                                  | GET    | /api/fmc_config/v1/domain/{domainUUID}/backup/files/{targetId}                                                                                       |
| deleteBackupFile                               | DELETE | /api/fmc_config/v1/domain/{domainUUID}/backup/files/{targetId}                                                                                       |
| createDeviceBackup                             | POST   | /api/fmc_config/v1/domain/{domainUUID}/backup/operational/devicebackup                                                                               |
| getAllTicket                                   | GET    | /api/fmc_config/v1/domain/{domainUUID}/changemanagement/tickets                                                                                      |
| createTicket                                   | POST   | /api/fmc_config/v1/domain/{domainUUID}/changemanagement/tickets                                                                                      |
| getTicketPreviewChange                         | GET    | /api/fmc_config/v1/domain/{domainUUID}/changemanagement/tickets/{containerUUID}/previewchanges                                                       |
| getTicketValidationResult                      | GET    | /api/fmc_config/v1/domain/{domainUUID}/changemanagement/tickets/{containerUUID}/validationresults                                                    |
| getTicket                                      | GET    | /api/fmc_config/v1/domain/{domainUUID}/changemanagement/tickets/{objectId}                                                                           |
| updateTicket                                   | PUT    | /api/fmc_config/v1/domain/{domainUUID}/changemanagement/tickets/{objectId}                                                                           |
| getAllFMCManagedChassis                        | GET    | /api/fmc_config/v1/domain/{domainUUID}/chassis/fmcmanagedchassis                                                                                     |
| createFMCManagedChassis                        | POST   | /api/fmc_config/v1/domain/{domainUUID}/chassis/fmcmanagedchassis                                                                                     |
| createChassisConversionModel                   | POST   | /api/fmc_config/v1/domain/{domainUUID}/chassis/fmcmanagedchassis/operational/switchmode                                                              |
| createDeviceConversionReadinessModel           | POST   | /api/fmc_config/v1/domain/{domainUUID}/chassis/fmcmanagedchassis/operational/switchmodereadinesscheck                                                |
| getChassisAppInfo                              | GET    | /api/fmc_config/v1/domain/{domainUUID}/chassis/fmcmanagedchassis/{containerUUID}/appinfo                                                             |
| getChassisInterfaceEvent                       | GET    | /api/fmc_config/v1/domain/{domainUUID}/chassis/fmcmanagedchassis/{containerUUID}/chassisinterfaceevents                                              |
| createChassisInterfaceEvent                    | POST   | /api/fmc_config/v1/domain/{domainUUID}/chassis/fmcmanagedchassis/{containerUUID}/chassisinterfaceevents                                              |
| getAllChassisInterface                         | GET    | /api/fmc_config/v1/domain/{domainUUID}/chassis/fmcmanagedchassis/{containerUUID}/chassisinterfaces                                                   |
| getChassisInterface                            | GET    | /api/fmc_config/v1/domain/{domainUUID}/chassis/fmcmanagedchassis/{containerUUID}/chassisinterfaces/{interfaceUUID}                                   |
| getEvaluateChassisOperation                    | GET    | /api/fmc_config/v1/domain/{domainUUID}/chassis/fmcmanagedchassis/{containerUUID}/chassisinterfaces/{interfaceUUID}/evaluateoperation                 |
| getAllEtherChannelInterface                    | GET    | /api/fmc_config/v1/domain/{domainUUID}/chassis/fmcmanagedchassis/{containerUUID}/etherchannelinterfaces                                              |
| createEtherChannelInterface                    | POST   | /api/fmc_config/v1/domain/{domainUUID}/chassis/fmcmanagedchassis/{containerUUID}/etherchannelinterfaces                                              |
| getEtherChannelInterface                       | GET    | /api/fmc_config/v1/domain/{domainUUID}/chassis/fmcmanagedchassis/{containerUUID}/etherchannelinterfaces/{interfaceUUID}                              |
| updateEtherChannelInterface                    | PUT    | /api/fmc_config/v1/domain/{domainUUID}/chassis/fmcmanagedchassis/{containerUUID}/etherchannelinterfaces/{interfaceUUID}                              |
| deleteEtherChannelInterface                    | DELETE | /api/fmc_config/v1/domain/{domainUUID}/chassis/fmcmanagedchassis/{containerUUID}/etherchannelinterfaces/{objectId}                                   |
| getChassisFaultSummary                         | GET    | /api/fmc_config/v1/domain/{domainUUID}/chassis/fmcmanagedchassis/{containerUUID}/faultsummary                                                        |
| getChassisInstanceSummary                      | GET    | /api/fmc_config/v1/domain/{domainUUID}/chassis/fmcmanagedchassis/{containerUUID}/instancesummary                                                     |
| getAllChassisAllInterfacesModel                | GET    | /api/fmc_config/v1/domain/{domainUUID}/chassis/fmcmanagedchassis/{containerUUID}/interfaces                                                          |
| getChassisAllInterfacesModel                   | GET    | /api/fmc_config/v1/domain/{domainUUID}/chassis/fmcmanagedchassis/{containerUUID}/interfaces/{interfaceUUID}                                          |
| getChassisInterfaceSummary                     | GET    | /api/fmc_config/v1/domain/{domainUUID}/chassis/fmcmanagedchassis/{containerUUID}/interfacesummary                                                    |
| getChassisInventorySummary                     | GET    | /api/fmc_config/v1/domain/{domainUUID}/chassis/fmcmanagedchassis/{containerUUID}/inventorysummary                                                    |
| getAllLogicalDevice                            | GET    | /api/fmc_config/v1/domain/{domainUUID}/chassis/fmcmanagedchassis/{containerUUID}/logicaldevices                                                      |
| createLogicalDevice                            | POST   | /api/fmc_config/v1/domain/{domainUUID}/chassis/fmcmanagedchassis/{containerUUID}/logicaldevices                                                      |
| getLogicalDevice                               | GET    | /api/fmc_config/v1/domain/{domainUUID}/chassis/fmcmanagedchassis/{containerUUID}/logicaldevices/{objectId}                                           |
| updateLogicalDevice                            | PUT    | /api/fmc_config/v1/domain/{domainUUID}/chassis/fmcmanagedchassis/{containerUUID}/logicaldevices/{objectId}                                           |
| deleteLogicalDevice                            | DELETE | /api/fmc_config/v1/domain/{domainUUID}/chassis/fmcmanagedchassis/{containerUUID}/logicaldevices/{objectId}                                           |
| getAllNetworkModule                            | GET    | /api/fmc_config/v1/domain/{domainUUID}/chassis/fmcmanagedchassis/{containerUUID}/networkmodules                                                      |
| getNetworkModule                               | GET    | /api/fmc_config/v1/domain/{domainUUID}/chassis/fmcmanagedchassis/{containerUUID}/networkmodules/{objectId}                                           |
| updateNetworkModule                            | PUT    | /api/fmc_config/v1/domain/{domainUUID}/chassis/fmcmanagedchassis/{containerUUID}/networkmodules/{objectId}                                           |
| createBreakoutInterface                        | POST   | /api/fmc_config/v1/domain/{domainUUID}/chassis/fmcmanagedchassis/{containerUUID}/operational/breakoutinterfaces                                      |
| createJoinInterface                            | POST   | /api/fmc_config/v1/domain/{domainUUID}/chassis/fmcmanagedchassis/{containerUUID}/operational/joininterfaces                                          |
| updateNetworkModuleSync                        | PUT    | /api/fmc_config/v1/domain/{domainUUID}/chassis/fmcmanagedchassis/{containerUUID}/operational/syncnetworkmodule                                       |
| getAllPhysicalInterface                        | GET    | /api/fmc_config/v1/domain/{domainUUID}/chassis/fmcmanagedchassis/{containerUUID}/physicalinterfaces                                                  |
| getPhysicalInterface                           | GET    | /api/fmc_config/v1/domain/{domainUUID}/chassis/fmcmanagedchassis/{containerUUID}/physicalinterfaces/{interfaceUUID}                                  |
| updatePhysicalInterface                        | PUT    | /api/fmc_config/v1/domain/{domainUUID}/chassis/fmcmanagedchassis/{containerUUID}/physicalinterfaces/{interfaceUUID}                                  |
| getAllChassisSnmpSettings                      | GET    | /api/fmc_config/v1/domain/{domainUUID}/chassis/fmcmanagedchassis/{containerUUID}/snmpsettings                                                        |
| getChassisSnmpSettings                         | GET    | /api/fmc_config/v1/domain/{domainUUID}/chassis/fmcmanagedchassis/{containerUUID}/snmpsettings/{objectId}                                             |
| updateChassisSnmpSettings                      | PUT    | /api/fmc_config/v1/domain/{domainUUID}/chassis/fmcmanagedchassis/{containerUUID}/snmpsettings/{objectId}                                             |
| getAllSubInterface                             | GET    | /api/fmc_config/v1/domain/{domainUUID}/chassis/fmcmanagedchassis/{containerUUID}/subinterfaces                                                       |
| createSubInterface                             | POST   | /api/fmc_config/v1/domain/{domainUUID}/chassis/fmcmanagedchassis/{containerUUID}/subinterfaces                                                       |
| getSubInterface                                | GET    | /api/fmc_config/v1/domain/{domainUUID}/chassis/fmcmanagedchassis/{containerUUID}/subinterfaces/{interfaceUUID}                                       |
| updateSubInterface                             | PUT    | /api/fmc_config/v1/domain/{domainUUID}/chassis/fmcmanagedchassis/{containerUUID}/subinterfaces/{interfaceUUID}                                       |
| deleteSubInterface                             | DELETE | /api/fmc_config/v1/domain/{domainUUID}/chassis/fmcmanagedchassis/{containerUUID}/subinterfaces/{objectId}                                            |
| getFMCManagedChassis                           | GET    | /api/fmc_config/v1/domain/{domainUUID}/chassis/fmcmanagedchassis/{objectId}                                                                          |
| deleteFMCManagedChassis                        | DELETE | /api/fmc_config/v1/domain/{domainUUID}/chassis/fmcmanagedchassis/{objectId}                                                                          |
| getDeployableDevice                            | GET    | /api/fmc_config/v1/domain/{domainUUID}/deployment/deployabledevices                                                                                  |
| getDeploymentDetail                            | GET    | /api/fmc_config/v1/domain/{domainUUID}/deployment/deployabledevices/{containerUUID}/deployments                                                      |
| getPendingChanges                              | GET    | /api/fmc_config/v1/domain/{domainUUID}/deployment/deployabledevices/{containerUUID}/pendingchanges                                                   |
| createDeploymentRequest                        | POST   | /api/fmc_config/v1/domain/{domainUUID}/deployment/deploymentrequests                                                                                 |
| getAllJobHistory                               | GET    | /api/fmc_config/v1/domain/{domainUUID}/deployment/jobhistories                                                                                       |
| getDownloadReport                              | GET    | /api/fmc_config/v1/domain/{domainUUID}/deployment/jobhistories/{containerUUID}/operational/downloadreports                                           |
| createEmailReport                              | POST   | /api/fmc_config/v1/domain/{domainUUID}/deployment/jobhistories/{containerUUID}/operational/emailreports                                              |
| getJobHistory                                  | GET    | /api/fmc_config/v1/domain/{domainUUID}/deployment/jobhistories/{objectId}                                                                            |
| updateJobHistory                               | PUT    | /api/fmc_config/v1/domain/{domainUUID}/deployment/jobhistories/{objectId}                                                                            |
| createPendingChangesRequest                    | POST   | /api/fmc_config/v1/domain/{domainUUID}/deployment/pendingchangesrequests                                                                             |
| createRollbackRequest                          | POST   | /api/fmc_config/v1/domain/{domainUUID}/deployment/rollbackrequests                                                                                   |
| createFTDClusterDeviceReadinessContainer       | POST   | /api/fmc_config/v1/domain/{domainUUID}/deviceclusters/ftdclusterreadinesscheck                                                                       |
| getAllRestFTDClusterDeviceContainer            | GET    | /api/fmc_config/v1/domain/{domainUUID}/deviceclusters/ftddevicecluster                                                                               |
| createRestFTDClusterDeviceContainer            | POST   | /api/fmc_config/v1/domain/{domainUUID}/deviceclusters/ftddevicecluster                                                                               |
| getClusterHealthMonitorSettingsModel           | GET    | /api/fmc_config/v1/domain/{domainUUID}/deviceclusters/ftddevicecluster/{containerUUID}/clusterhealthmonitorsettings/{clusterUuid}                    |
| updateClusterHealthMonitorSettingsModel        | PUT    | /api/fmc_config/v1/domain/{domainUUID}/deviceclusters/ftddevicecluster/{containerUUID}/clusterhealthmonitorsettings/{clusterUuid}                    |
| getRestFTDClusterDeviceContainer               | GET    | /api/fmc_config/v1/domain/{domainUUID}/deviceclusters/ftddevicecluster/{objectId}                                                                    |
| updateRestFTDClusterDeviceContainer            | PUT    | /api/fmc_config/v1/domain/{domainUUID}/deviceclusters/ftddevicecluster/{objectId}                                                                    |
| deleteRestFTDClusterDeviceContainer            | DELETE | /api/fmc_config/v1/domain/{domainUUID}/deviceclusters/ftddevicecluster/{objectId}                                                                    |
| createFTDClusterDeviceCommandContainer         | POST   | /api/fmc_config/v1/domain/{domainUUID}/deviceclusters/{containerUUID}/operational/ftdclusterdevicecommands                                           |
| getAllDeviceGroup                              | GET    | /api/fmc_config/v1/domain/{domainUUID}/devicegroups/devicegrouprecords                                                                               |
| createDeviceGroup                              | POST   | /api/fmc_config/v1/domain/{domainUUID}/devicegroups/devicegrouprecords                                                                               |
| getDeviceGroup                                 | GET    | /api/fmc_config/v1/domain/{domainUUID}/devicegroups/devicegrouprecords/{objectId}                                                                    |
| updateDeviceGroup                              | PUT    | /api/fmc_config/v1/domain/{domainUUID}/devicegroups/devicegrouprecords/{objectId}                                                                    |
| deleteDeviceGroup                              | DELETE | /api/fmc_config/v1/domain/{domainUUID}/devicegroups/devicegrouprecords/{objectId}                                                                    |
| getAllFTDHADeviceContainer                     | GET    | /api/fmc_config/v1/domain/{domainUUID}/devicehapairs/ftddevicehapairs                                                                                |
| createFTDHADeviceContainer                     | POST   | /api/fmc_config/v1/domain/{domainUUID}/devicehapairs/ftddevicehapairs                                                                                |
| getAllFTDHAInterfaceMACAddresses               | GET    | /api/fmc_config/v1/domain/{domainUUID}/devicehapairs/ftddevicehapairs/{containerUUID}/failoverinterfacemacaddressconfigs                             |
| createFTDHAInterfaceMACAddresses               | POST   | /api/fmc_config/v1/domain/{domainUUID}/devicehapairs/ftddevicehapairs/{containerUUID}/failoverinterfacemacaddressconfigs                             |
| getFTDHAInterfaceMACAddresses                  | GET    | /api/fmc_config/v1/domain/{domainUUID}/devicehapairs/ftddevicehapairs/{containerUUID}/failoverinterfacemacaddressconfigs/{objectId}                  |
| updateFTDHAInterfaceMACAddresses               | PUT    | /api/fmc_config/v1/domain/{domainUUID}/devicehapairs/ftddevicehapairs/{containerUUID}/failoverinterfacemacaddressconfigs/{objectId}                  |
| deleteFTDHAInterfaceMACAddresses               | DELETE | /api/fmc_config/v1/domain/{domainUUID}/devicehapairs/ftddevicehapairs/{containerUUID}/failoverinterfacemacaddressconfigs/{objectId}                  |
| getAllFTDHAMonitoredInterfaces                 | GET    | /api/fmc_config/v1/domain/{domainUUID}/devicehapairs/ftddevicehapairs/{containerUUID}/monitoredinterfaces                                            |
| getFTDHAMonitoredInterfaces                    | GET    | /api/fmc_config/v1/domain/{domainUUID}/devicehapairs/ftddevicehapairs/{containerUUID}/monitoredinterfaces/{objectId}                                 |
| updateFTDHAMonitoredInterfaces                 | PUT    | /api/fmc_config/v1/domain/{domainUUID}/devicehapairs/ftddevicehapairs/{containerUUID}/monitoredinterfaces/{objectId}                                 |
| getFTDHADeviceContainer                        | GET    | /api/fmc_config/v1/domain/{domainUUID}/devicehapairs/ftddevicehapairs/{objectId}                                                                     |
| updateFTDHADeviceContainer                     | PUT    | /api/fmc_config/v1/domain/{domainUUID}/devicehapairs/ftddevicehapairs/{objectId}                                                                     |
| deleteFTDHADeviceContainer                     | DELETE | /api/fmc_config/v1/domain/{domainUUID}/devicehapairs/ftddevicehapairs/{objectId}                                                                     |
| createDeviceCopyConfigRequest                  | POST   | /api/fmc_config/v1/domain/{domainUUID}/devices/copyconfigrequests                                                                                    |
| getAllDevice                                   | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords                                                                                         |
| createMultipleDevice                           | POST   | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords                                                                                         |
| deleteMultipleDevice                           | DELETE | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords                                                                                         |
| getAllFTDBridgeGroupInterface                  | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/bridgegroupinterfaces                                                   |
| createFTDBridgeGroupInterface                  | POST   | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/bridgegroupinterfaces                                                   |
| getFTDBridgeGroupInterface                     | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/bridgegroupinterfaces/{objectId}                                        |
| updateFTDBridgeGroupInterface                  | PUT    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/bridgegroupinterfaces/{objectId}                                        |
| deleteFTDBridgeGroupInterface                  | DELETE | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/bridgegroupinterfaces/{objectId}                                        |
| getAllDeviceDDNSSettingModel                   | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/dhcp/ddnssettings                                                       |
| getDeviceDDNSSettingModel                      | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/dhcp/ddnssettings/{objectId}                                            |
| updateDeviceDDNSSettingModel                   | PUT    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/dhcp/ddnssettings/{objectId}                                            |
| getAllDeviceDHCPRelaySettings                  | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/dhcp/dhcprelaysettings                                                  |
| getDeviceDHCPRelaySettings                     | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/dhcp/dhcprelaysettings/{objectId}                                       |
| updateDeviceDHCPRelaySettings                  | PUT    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/dhcp/dhcprelaysettings/{objectId}                                       |
| getAllDeviceDHCPServerSettings                 | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/dhcp/dhcpserver                                                         |
| getDeviceDHCPServerSettings                    | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/dhcp/dhcpserver/{objectId}                                              |
| updateDeviceDHCPServerSettings                 | PUT    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/dhcp/dhcpserver/{objectId}                                              |
| getAllFTDEtherChannelInterface                 | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/etherchannelinterfaces                                                  |
| createFTDEtherChannelInterface                 | POST   | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/etherchannelinterfaces                                                  |
| getFTDEtherChannelInterface                    | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/etherchannelinterfaces/{objectId}                                       |
| updateFTDEtherChannelInterface                 | PUT    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/etherchannelinterfaces/{objectId}                                       |
| deleteFTDEtherChannelInterface                 | DELETE | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/etherchannelinterfaces/{objectId}                                       |
| getFPInterfaceStatistics                       | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/fpinterfacestatistics                                                   |
| getAllFPLogicalInterface                       | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/fplogicalinterfaces                                                     |
| createFPLogicalInterface                       | POST   | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/fplogicalinterfaces                                                     |
| getFPLogicalInterface                          | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/fplogicalinterfaces/{objectId}                                          |
| updateFPLogicalInterface                       | PUT    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/fplogicalinterfaces/{objectId}                                          |
| deleteFPLogicalInterface                       | DELETE | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/fplogicalinterfaces/{objectId}                                          |
| getAllFPPhysicalInterface                      | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/fpphysicalinterfaces                                                    |
| getFPPhysicalInterface                         | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/fpphysicalinterfaces/{objectId}                                         |
| updateFPPhysicalInterface                      | PUT    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/fpphysicalinterfaces/{objectId}                                         |
| getFTDAllInterfacesModel                       | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/ftdallinterfaces                                                        |
| getAllInlineSet                                | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/inlinesets                                                              |
| createInlineSet                                | POST   | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/inlinesets                                                              |
| getInlineSet                                   | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/inlinesets/{objectId}                                                   |
| updateInlineSet                                | PUT    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/inlinesets/{objectId}                                                   |
| deleteInlineSet                                | DELETE | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/inlinesets/{objectId}                                                   |
| getInterfaceEvent                              | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/interfaceevents                                                         |
| createInterfaceEvent                           | POST   | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/interfaceevents                                                         |
| getAllFTDLoopbackInterface                     | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/loopbackinterfaces                                                      |
| createFTDLoopbackInterface                     | POST   | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/loopbackinterfaces                                                      |
| getFTDLoopbackInterface                        | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/loopbackinterfaces/{objectId}                                           |
| updateFTDLoopbackInterface                     | PUT    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/loopbackinterfaces/{objectId}                                           |
| deleteFTDLoopbackInterface                     | DELETE | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/loopbackinterfaces/{objectId}                                           |
| getManagementInterfaceConvergence              | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/managementconvergencemode                                               |
| createManagementInterfaceConvergence           | POST   | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/managementconvergencemode                                               |
| getCommands                                    | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/operational/commands                                                    |
| getHealthMonitorModel                          | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/operational/metrics                                                     |
| getAllVirtualAccessInterface                   | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/operational/virtualaccessinterfaces                                     |
| getAllFTDPhysicalInterface                     | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/physicalinterfaces                                                      |
| getFTDPhysicalInterface                        | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/physicalinterfaces/{objectId}                                           |
| updateFTDPhysicalInterface                     | PUT    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/physicalinterfaces/{objectId}                                           |
| getAllFTDRedundantInterface                    | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/redundantinterfaces                                                     |
| createFTDRedundantInterface                    | POST   | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/redundantinterfaces                                                     |
| getFTDRedundantInterface                       | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/redundantinterfaces/{objectId}                                          |
| updateFTDRedundantInterface                    | PUT    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/redundantinterfaces/{objectId}                                          |
| deleteFTDRedundantInterface                    | DELETE | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/redundantinterfaces/{objectId}                                          |
| getAllBFDPolicyModel                           | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/bfdpolicies                                                     |
| createBFDPolicyModel                           | POST   | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/bfdpolicies                                                     |
| getBFDPolicyModel                              | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/bfdpolicies/{objectId}                                          |
| updateBFDPolicyModel                           | PUT    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/bfdpolicies/{objectId}                                          |
| deleteBFDPolicyModel                           | DELETE | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/bfdpolicies/{objectId}                                          |
| getAllBGPIPvAddressFamilyModel                 | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/bgp                                                             |
| createBGPIPvAddressFamilyModel                 | POST   | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/bgp                                                             |
| getBGPIPvAddressFamilyModel                    | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/bgp/{objectId}                                                  |
| updateBGPIPvAddressFamilyModel                 | PUT    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/bgp/{objectId}                                                  |
| deleteBGPIPvAddressFamilyModel                 | DELETE | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/bgp/{objectId}                                                  |
| getAllBGPGeneralSettingModel                   | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/bgpgeneralsettings                                              |
| createBGPGeneralSettingModel                   | POST   | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/bgpgeneralsettings                                              |
| getBGPGeneralSettingModel                      | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/bgpgeneralsettings/{objectId}                                   |
| updateBGPGeneralSettingModel                   | PUT    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/bgpgeneralsettings/{objectId}                                   |
| deleteBGPGeneralSettingModel                   | DELETE | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/bgpgeneralsettings/{objectId}                                   |
| getAllECMPZoneModel                            | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/ecmpzones                                                       |
| createECMPZoneModel                            | POST   | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/ecmpzones                                                       |
| getECMPZoneModel                               | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/ecmpzones/{objectId}                                            |
| updateECMPZoneModel                            | PUT    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/ecmpzones/{objectId}                                            |
| deleteECMPZoneModel                            | DELETE | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/ecmpzones/{objectId}                                            |
| getAllEigrpPolicyModel                         | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/eigrproutes                                                     |
| createEigrpPolicyModel                         | POST   | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/eigrproutes                                                     |
| getEigrpPolicyModel                            | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/eigrproutes/{objectId}                                          |
| updateEigrpPolicyModel                         | PUT    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/eigrproutes/{objectId}                                          |
| deleteEigrpPolicyModel                         | DELETE | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/eigrproutes/{objectId}                                          |
| getAllIPv4StaticRouteModel                     | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/ipv4staticroutes                                                |
| createMultipleIPv4StaticRouteModel             | POST   | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/ipv4staticroutes                                                |
| getIPv4StaticRouteModel                        | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/ipv4staticroutes/{objectId}                                     |
| updateIPv4StaticRouteModel                     | PUT    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/ipv4staticroutes/{objectId}                                     |
| deleteIPv4StaticRouteModel                     | DELETE | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/ipv4staticroutes/{objectId}                                     |
| getAllIPv6StaticRouteModel                     | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/ipv6staticroutes                                                |
| createMultipleIPv6StaticRouteModel             | POST   | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/ipv6staticroutes                                                |
| getIPv6StaticRouteModel                        | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/ipv6staticroutes/{objectId}                                     |
| updateIPv6StaticRouteModel                     | PUT    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/ipv6staticroutes/{objectId}                                     |
| deleteIPv6StaticRouteModel                     | DELETE | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/ipv6staticroutes/{objectId}                                     |
| getAllOspfInterfacePolicyModel                 | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/ospfinterface                                                   |
| getOspfInterfacePolicyModel                    | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/ospfinterface/{objectId}                                        |
| getAllOspfPolicyModel                          | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/ospfv2routes                                                    |
| getOspfPolicyModel                             | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/ospfv2routes/{objectId}                                         |
| getAllOspfv3InterfacePolicyModel               | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/ospfv3interfaces                                                |
| getOspfv3InterfacePolicyModel                  | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/ospfv3interfaces/{objectId}                                     |
| getAllOspfv3PolicyModel                        | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/ospfv3routes                                                    |
| getOspfv3PolicyModel                           | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/ospfv3routes/{objectId}                                         |
| getAllPBRPolicyModel                           | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/policybasedroutes                                               |
| createMultiplePBRPolicyModel                   | POST   | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/policybasedroutes                                               |
| getPBRPolicyModel                              | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/policybasedroutes/{objectId}                                    |
| updatePBRPolicyModel                           | PUT    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/policybasedroutes/{objectId}                                    |
| deletePBRPolicyModel                           | DELETE | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/policybasedroutes/{objectId}                                    |
| getAllStaticRouteModel                         | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/staticroutes                                                    |
| getStaticRouteModel                            | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/staticroutes/{objectId}                                         |
| getAllVirtualRouterModel                       | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/virtualrouters                                                  |
| createVirtualRouterModel                       | POST   | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/virtualrouters                                                  |
| getVirtualRouterModel                          | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/virtualrouters/{objectId}                                       |
| updateVirtualRouterModel                       | PUT    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/virtualrouters/{objectId}                                       |
| deleteVirtualRouterModel                       | DELETE | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/virtualrouters/{objectId}                                       |
| getAllVrfBFDPolicyModel                        | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/virtualrouters/{virtualrouterUUID}/bfdpolicies                  |
| createVrfBFDPolicyModel                        | POST   | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/virtualrouters/{virtualrouterUUID}/bfdpolicies                  |
| getVrfBFDPolicyModel                           | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/virtualrouters/{virtualrouterUUID}/bfdpolicies/{objectId}       |
| updateVrfBFDPolicyModel                        | PUT    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/virtualrouters/{virtualrouterUUID}/bfdpolicies/{objectId}       |
| deleteVrfBFDPolicyModel                        | DELETE | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/virtualrouters/{virtualrouterUUID}/bfdpolicies/{objectId}       |
| getAllVrfBGPIPvAddressFamilyModel              | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/virtualrouters/{virtualrouterUUID}/bgp                          |
| createVrfBGPIPvAddressFamilyModel              | POST   | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/virtualrouters/{virtualrouterUUID}/bgp                          |
| getVrfBGPIPvAddressFamilyModel                 | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/virtualrouters/{virtualrouterUUID}/bgp/{objectId}               |
| updateVrfBGPIPvAddressFamilyModel              | PUT    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/virtualrouters/{virtualrouterUUID}/bgp/{objectId}               |
| deleteVrfBGPIPvAddressFamilyModel              | DELETE | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/virtualrouters/{virtualrouterUUID}/bgp/{objectId}               |
| getAllVrfECMPZoneModel                         | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/virtualrouters/{virtualrouterUUID}/ecmpzones                    |
| createVrfECMPZoneModel                         | POST   | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/virtualrouters/{virtualrouterUUID}/ecmpzones                    |
| getVrfECMPZoneModel                            | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/virtualrouters/{virtualrouterUUID}/ecmpzones/{objectId}         |
| updateVrfECMPZoneModel                         | PUT    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/virtualrouters/{virtualrouterUUID}/ecmpzones/{objectId}         |
| deleteVrfECMPZoneModel                         | DELETE | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/virtualrouters/{virtualrouterUUID}/ecmpzones/{objectId}         |
| getAllVrfEigrpPolicyModel                      | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/virtualrouters/{virtualrouterUUID}/eigrproutes                  |
| createVrfEigrpPolicyModel                      | POST   | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/virtualrouters/{virtualrouterUUID}/eigrproutes                  |
| getVrfEigrpPolicyModel                         | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/virtualrouters/{virtualrouterUUID}/eigrproutes/{objectId}       |
| updateVrfEigrpPolicyModel                      | PUT    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/virtualrouters/{virtualrouterUUID}/eigrproutes/{objectId}       |
| deleteVrfEigrpPolicyModel                      | DELETE | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/virtualrouters/{virtualrouterUUID}/eigrproutes/{objectId}       |
| getAllVrfIPv4StaticRouteModel                  | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/virtualrouters/{virtualrouterUUID}/ipv4staticroutes             |
| createVrfIPv4StaticRouteModel                  | POST   | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/virtualrouters/{virtualrouterUUID}/ipv4staticroutes             |
| getVrfIPv4StaticRouteModel                     | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/virtualrouters/{virtualrouterUUID}/ipv4staticroutes/{objectId}  |
| updateVrfIPv4StaticRouteModel                  | PUT    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/virtualrouters/{virtualrouterUUID}/ipv4staticroutes/{objectId}  |
| deleteVrfIPv4StaticRouteModel                  | DELETE | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/virtualrouters/{virtualrouterUUID}/ipv4staticroutes/{objectId}  |
| getAllVrfIPv6StaticRouteModel                  | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/virtualrouters/{virtualrouterUUID}/ipv6staticroutes             |
| createVrfIPv6StaticRouteModel                  | POST   | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/virtualrouters/{virtualrouterUUID}/ipv6staticroutes             |
| getVrfIPv6StaticRouteModel                     | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/virtualrouters/{virtualrouterUUID}/ipv6staticroutes/{objectId}  |
| updateVrfIPv6StaticRouteModel                  | PUT    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/virtualrouters/{virtualrouterUUID}/ipv6staticroutes/{objectId}  |
| deleteVrfIPv6StaticRouteModel                  | DELETE | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/virtualrouters/{virtualrouterUUID}/ipv6staticroutes/{objectId}  |
| getAllVrfOspfInterfacePolicyModel              | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/virtualrouters/{virtualrouterUUID}/ospfinterface                |
| getVrfOspfInterfacePolicyModel                 | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/virtualrouters/{virtualrouterUUID}/ospfinterface/{objectId}     |
| getAllVrfOspfPolicyModel                       | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/virtualrouters/{virtualrouterUUID}/ospfv2routes                 |
| getVrfOspfPolicyModel                          | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/virtualrouters/{virtualrouterUUID}/ospfv2routes/{objectId}      |
| getAllVrfPBRPolicyModel                        | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/virtualrouters/{virtualrouterUUID}/policybasedroutes            |
| createVrfPBRPolicyModel                        | POST   | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/virtualrouters/{virtualrouterUUID}/policybasedroutes            |
| getVrfPBRPolicyModel                           | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/virtualrouters/{virtualrouterUUID}/policybasedroutes/{objectId} |
| updateVrfPBRPolicyModel                        | PUT    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/virtualrouters/{virtualrouterUUID}/policybasedroutes/{objectId} |
| deleteVrfPBRPolicyModel                        | DELETE | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/virtualrouters/{virtualrouterUUID}/policybasedroutes/{objectId} |
| getAllVrfStaticRouteModel                      | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/virtualrouters/{virtualrouterUUID}/staticroutes                 |
| getVrfStaticRouteModel                         | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/routing/virtualrouters/{virtualrouterUUID}/staticroutes/{objectId}      |
| getAllFTDSubInterface                          | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/subinterfaces                                                           |
| createMultipleFTDSubInterface                  | POST   | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/subinterfaces                                                           |
| getFTDSubInterface                             | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/subinterfaces/{objectId}                                                |
| updateFTDSubInterface                          | PUT    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/subinterfaces/{objectId}                                                |
| deleteFTDSubInterface                          | DELETE | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/subinterfaces/{objectId}                                                |
| getAllVirtualSwitch                            | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/virtualswitches                                                         |
| createVirtualSwitch                            | POST   | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/virtualswitches                                                         |
| getVirtualSwitch                               | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/virtualswitches/{objectId}                                              |
| updateVirtualSwitch                            | PUT    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/virtualswitches/{objectId}                                              |
| deleteVirtualSwitch                            | DELETE | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/virtualswitches/{objectId}                                              |
| getAllFTDVTIInterface                          | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/virtualtunnelinterfaces                                                 |
| createMultipleFTDVTIInterface                  | POST   | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/virtualtunnelinterfaces                                                 |
| getFTDVTIInterface                             | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/virtualtunnelinterfaces/{objectId}                                      |
| updateFTDVTIInterface                          | PUT    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/virtualtunnelinterfaces/{objectId}                                      |
| deleteFTDVTIInterface                          | DELETE | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/virtualtunnelinterfaces/{objectId}                                      |
| getAllFTDVlanInterface                         | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/vlaninterfaces                                                          |
| createFTDVlanInterface                         | POST   | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/vlaninterfaces                                                          |
| getFTDVlanInterface                            | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/vlaninterfaces/{objectId}                                               |
| updateFTDVlanInterface                         | PUT    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/vlaninterfaces/{objectId}                                               |
| deleteFTDVlanInterface                         | DELETE | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/vlaninterfaces/{objectId}                                               |
| getAllFTDVNIInterface                          | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/vniinterfaces                                                           |
| createFTDVNIInterface                          | POST   | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/vniinterfaces                                                           |
| getFTDVNIInterface                             | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/vniinterfaces/{objectId}                                                |
| updateFTDVNIInterface                          | PUT    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/vniinterfaces/{objectId}                                                |
| deleteFTDVNIInterface                          | DELETE | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/vniinterfaces/{objectId}                                                |
| getAllVTEPPolicy                               | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/vteppolicies                                                            |
| createVTEPPolicy                               | POST   | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/vteppolicies                                                            |
| getVTEPPolicy                                  | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/vteppolicies/{objectId}                                                 |
| updateVTEPPolicy                               | PUT    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/vteppolicies/{objectId}                                                 |
| deleteVTEPPolicy                               | DELETE | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{containerUUID}/vteppolicies/{objectId}                                                 |
| getDevice                                      | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{objectId}                                                                              |
| updateDevice                                   | PUT    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{objectId}                                                                              |
| deleteDevice                                   | DELETE | /api/fmc_config/v1/domain/{domainUUID}/devices/devicerecords/{objectId}                                                                              |
| getAllDeviceSettings                           | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicesettings                                                                                        |
| updateMultipleDeviceSettings                   | PUT    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicesettings                                                                                        |
| getDeviceSettings                              | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicesettings/{containerUUID}                                                                        |
| updateDeviceSettings                           | PUT    | /api/fmc_config/v1/domain/{domainUUID}/devices/devicesettings/{containerUUID}                                                                        |
| getAllLTPDeviceRecord                          | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/ltpdevicerecords                                                                                      |
| getLTPDeviceRecord                             | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/ltpdevicerecords/{objectId}                                                                           |
| deleteLTPDeviceRecord                          | DELETE | /api/fmc_config/v1/domain/{domainUUID}/devices/ltpdevicerecords/{objectId}                                                                           |
| createBulkRegistration                         | POST   | /api/fmc_config/v1/domain/{domainUUID}/devices/operational/bulkregistrations                                                                         |
| getDownloadSampleCsv                           | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/operational/bulkregistrations/downloadsamplecsv                                                       |
| createChangeConfigManagerFTDRequest            | POST   | /api/fmc_config/v1/domain/{domainUUID}/devices/operational/changemanagers                                                                            |
| createDeviceExport                             | POST   | /api/fmc_config/v1/domain/{domainUUID}/devices/operational/exports                                                                                   |
| createDeviceImport                             | POST   | /api/fmc_config/v1/domain/{domainUUID}/devices/operational/imports                                                                                   |
| getAllSFCNCluster                              | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/sfcnclusters                                                                                          |
| createSFCNCluster                              | POST   | /api/fmc_config/v1/domain/{domainUUID}/devices/sfcnclusters                                                                                          |
| createArchiveSnapshot                          | POST   | /api/fmc_config/v1/domain/{domainUUID}/devices/sfcnclusters/{containerUUID}/operational/archivesnapshot                                              |
| getSFCNCluster                                 | GET    | /api/fmc_config/v1/domain/{domainUUID}/devices/sfcnclusters/{objectId}                                                                               |
| updateSFCNCluster                              | PUT    | /api/fmc_config/v1/domain/{domainUUID}/devices/sfcnclusters/{objectId}                                                                               |
| deleteSFCNCluster                              | DELETE | /api/fmc_config/v1/domain/{domainUUID}/devices/sfcnclusters/{objectId}                                                                               |
| getHealthAlertModel                            | GET    | /api/fmc_config/v1/domain/{domainUUID}/health/alerts                                                                                                 |
| getHealthEventModel                            | GET    | /api/fmc_config/v1/domain/{domainUUID}/health/events                                                                                                 |
| getHealthMetric                                | GET    | /api/fmc_config/v1/domain/{domainUUID}/health/metrics                                                                                                |
| getAllPathMonitoredInterface                   | GET    | /api/fmc_config/v1/domain/{domainUUID}/health/pathmonitoredinterfaces                                                                                |
| getRaVpnGateway                                | GET    | /api/fmc_config/v1/domain/{domainUUID}/health/ravpngateways                                                                                          |
| createTerminateRAVPNSession                    | POST   | /api/fmc_config/v1/domain/{domainUUID}/health/ravpnsessions/operational/terminateravpnsessions                                                       |
| getAllTunnelStatus                             | GET    | /api/fmc_config/v1/domain/{domainUUID}/health/tunnelstatuses                                                                                         |
| getAllTunnelDetail                             | GET    | /api/fmc_config/v1/domain/{domainUUID}/health/tunnelstatuses/{containerUUID}/tunneldetails                                                           |
| getTunnelStatus                                | GET    | /api/fmc_config/v1/domain/{domainUUID}/health/tunnelstatuses/{objectId}                                                                              |
| getTunnelSummary                               | GET    | /api/fmc_config/v1/domain/{domainUUID}/health/tunnelsummaries                                                                                        |
| createBackup                                   | POST   | /api/fmc_config/v1/domain/{domainUUID}/integration/backuptask                                                                                        |
| createCdFMCSnapshot                            | POST   | /api/fmc_config/v1/domain/{domainUUID}/integration/cdfmcsnapshot                                                                                     |
| getCdFMCSnapshot                               | GET    | /api/fmc_config/v1/domain/{domainUUID}/integration/cdfmcsnapshot/{objectId}                                                                          |
| getAllCloudEvents                              | GET    | /api/fmc_config/v1/domain/{domainUUID}/integration/cloudeventsconfigs                                                                                |
| getCloudEvents                                 | GET    | /api/fmc_config/v1/domain/{domainUUID}/integration/cloudeventsconfigs/{objectId}                                                                     |
| updateCloudEvents                              | PUT    | /api/fmc_config/v1/domain/{domainUUID}/integration/cloudeventsconfigs/{objectId}                                                                     |
| getAllCloudRegion                              | GET    | /api/fmc_config/v1/domain/{domainUUID}/integration/cloudregions                                                                                      |
| getCloudRegion                                 | GET    | /api/fmc_config/v1/domain/{domainUUID}/integration/cloudregions/{objectId}                                                                           |
| updateCloudRegion                              | PUT    | /api/fmc_config/v1/domain/{domainUUID}/integration/cloudregions/{objectId}                                                                           |
| createEBSSnapshot                              | POST   | /api/fmc_config/v1/domain/{domainUUID}/integration/ebssnapshot                                                                                       |
| getEBSSnapshot                                 | GET    | /api/fmc_config/v1/domain/{domainUUID}/integration/ebssnapshot/{objectId}                                                                            |
| getAllExternalLookup                           | GET    | /api/fmc_config/v1/domain/{domainUUID}/integration/externallookups                                                                                   |
| createExternalLookup                           | POST   | /api/fmc_config/v1/domain/{domainUUID}/integration/externallookups                                                                                   |
| getExternalLookup                              | GET    | /api/fmc_config/v1/domain/{domainUUID}/integration/externallookups/{objectId}                                                                        |
| updateExternalLookup                           | PUT    | /api/fmc_config/v1/domain/{domainUUID}/integration/externallookups/{objectId}                                                                        |
| deleteExternalLookup                           | DELETE | /api/fmc_config/v1/domain/{domainUUID}/integration/externallookups/{objectId}                                                                        |
| getAllExternalStorage                          | GET    | /api/fmc_config/v1/domain/{domainUUID}/integration/externalstorage                                                                                   |
| getExternalStorage                             | GET    | /api/fmc_config/v1/domain/{domainUUID}/integration/externalstorage/{objectId}                                                                        |
| updateExternalStorage                          | PUT    | /api/fmc_config/v1/domain/{domainUUID}/integration/externalstorage/{objectId}                                                                        |
| getFMCHAStatus                                 | GET    | /api/fmc_config/v1/domain/{domainUUID}/integration/fmchastatuses                                                                                     |
| createSecurexConfigRefresh                     | POST   | /api/fmc_config/v1/domain/{domainUUID}/integration/operational/refreshsecurexconfigs                                                                 |
| createTestUmbrellaConnection                   | POST   | /api/fmc_config/v1/domain/{domainUUID}/integration/operational/testumbrellaconnections                                                               |
| getAllUmbrellaDataCenter                       | GET    | /api/fmc_config/v1/domain/{domainUUID}/integration/umbrella/datacenters                                                                              |
| createUmbrellaDeploymentData                   | POST   | /api/fmc_config/v1/domain/{domainUUID}/integration/umbrella/tunneldeployments                                                                        |
| getUmbrellaDeploymentTranscript                | GET    | /api/fmc_config/v1/domain/{domainUUID}/integration/umbrella/tunneldeployments/{containerUUID}/transcripts/{objectId}                                 |
| getUmbrellaDeploymentData                      | GET    | /api/fmc_config/v1/domain/{domainUUID}/integration/umbrella/tunneldeployments/{objectId}                                                             |
| getAllUmbrellaConnection                       | GET    | /api/fmc_config/v1/domain/{domainUUID}/integration/umbrellaconnections                                                                               |
| getUmbrellaConnection                          | GET    | /api/fmc_config/v1/domain/{domainUUID}/integration/umbrellaconnections/{objectId}                                                                    |
| updateUmbrellaConnection                       | PUT    | /api/fmc_config/v1/domain/{domainUUID}/integration/umbrellaconnections/{objectId}                                                                    |
| getAllTaskStatus                               | GET    | /api/fmc_config/v1/domain/{domainUUID}/job/taskstatuses                                                                                              |
| getTaskStatus                                  | GET    | /api/fmc_config/v1/domain/{domainUUID}/job/taskstatuses/{objectId}                                                                                   |
| getTaskDownloadReport                          | GET    | /api/fmc_config/v1/domain/{domainUUID}/job/taskstatuses/{objectId}/operational/downloadreports                                                       |
| getAllAnyConnectCustomAttributeModel           | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/anyconnectcustomattributes                                                                             |
| createAnyConnectCustomAttributeModel           | POST   | /api/fmc_config/v1/domain/{domainUUID}/object/anyconnectcustomattributes                                                                             |
| getAnyConnectCustomAttributeOverride           | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/anyconnectcustomattributes/{containerUUID}/overrides                                                   |
| getAnyConnectCustomAttributeModel              | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/anyconnectcustomattributes/{objectId}                                                                  |
| updateAnyConnectCustomAttributeModel           | PUT    | /api/fmc_config/v1/domain/{domainUUID}/object/anyconnectcustomattributes/{objectId}                                                                  |
| deleteAnyConnectCustomAttributeModel           | DELETE | /api/fmc_config/v1/domain/{domainUUID}/object/anyconnectcustomattributes/{objectId}                                                                  |
| getAllAnyConnectExternalBrowserPackageModel    | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/anyconnectexternalbrowserpackages                                                                      |
| createAnyConnectExternalBrowserPackageModel    | POST   | /api/fmc_config/v1/domain/{domainUUID}/object/anyconnectexternalbrowserpackages                                                                      |
| getAnyConnectExternalBrowserPackageModel       | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/anyconnectexternalbrowserpackages/{objectId}                                                           |
| updateAnyConnectExternalBrowserPackageModel    | PUT    | /api/fmc_config/v1/domain/{domainUUID}/object/anyconnectexternalbrowserpackages/{objectId}                                                           |
| deleteAnyConnectExternalBrowserPackageModel    | DELETE | /api/fmc_config/v1/domain/{domainUUID}/object/anyconnectexternalbrowserpackages/{objectId}                                                           |
| getAllAnyConnectPackageModel                   | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/anyconnectpackages                                                                                     |
| createAnyConnectPackageModel                   | POST   | /api/fmc_config/v1/domain/{domainUUID}/object/anyconnectpackages                                                                                     |
| getAnyConnectPackageModel                      | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/anyconnectpackages/{objectId}                                                                          |
| updateAnyConnectPackageModel                   | PUT    | /api/fmc_config/v1/domain/{domainUUID}/object/anyconnectpackages/{objectId}                                                                          |
| deleteAnyConnectPackageModel                   | DELETE | /api/fmc_config/v1/domain/{domainUUID}/object/anyconnectpackages/{objectId}                                                                          |
| getAllAnyConnectProfileModel                   | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/anyconnectprofiles                                                                                     |
| createAnyConnectProfileModel                   | POST   | /api/fmc_config/v1/domain/{domainUUID}/object/anyconnectprofiles                                                                                     |
| getAnyConnectProfileModel                      | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/anyconnectprofiles/{objectId}                                                                          |
| updateAnyConnectProfileModel                   | PUT    | /api/fmc_config/v1/domain/{domainUUID}/object/anyconnectprofiles/{objectId}                                                                          |
| deleteAnyConnectProfileModel                   | DELETE | /api/fmc_config/v1/domain/{domainUUID}/object/anyconnectprofiles/{objectId}                                                                          |
| getAllAnyProtocolPortObject                    | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/anyprotocolportobjects                                                                                 |
| getAnyProtocolPortObject                       | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/anyprotocolportobjects/{objectId}                                                                      |
| getAllApplicationCategory                      | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/applicationcategories                                                                                  |
| getApplicationCategory                         | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/applicationcategories/{objectId}                                                                       |
| getAllApplicationFilter                        | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/applicationfilters                                                                                     |
| createApplicationFilter                        | POST   | /api/fmc_config/v1/domain/{domainUUID}/object/applicationfilters                                                                                     |
| getApplicationFilter                           | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/applicationfilters/{objectId}                                                                          |
| updateApplicationFilter                        | PUT    | /api/fmc_config/v1/domain/{domainUUID}/object/applicationfilters/{objectId}                                                                          |
| deleteApplicationFilter                        | DELETE | /api/fmc_config/v1/domain/{domainUUID}/object/applicationfilters/{objectId}                                                                          |
| getAllApplicationProductivity                  | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/applicationproductivities                                                                              |
| getApplicationProductivity                     | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/applicationproductivities/{objectId}                                                                   |
| getAllApplicationRisk                          | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/applicationrisks                                                                                       |
| getApplicationRisk                             | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/applicationrisks/{objectId}                                                                            |
| getAllApplication                              | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/applications                                                                                           |
| getApplication                                 | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/applications/{objectId}                                                                                |
| getAllApplicationTag                           | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/applicationtags                                                                                        |
| getApplicationTag                              | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/applicationtags/{objectId}                                                                             |
| getAllApplicationType                          | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/applicationtypes                                                                                       |
| getApplicationType                             | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/applicationtypes/{objectId}                                                                            |
| getAllAsPathList                               | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/aspathlists                                                                                            |
| createAsPathList                               | POST   | /api/fmc_config/v1/domain/{domainUUID}/object/aspathlists                                                                                            |
| getAsPathList                                  | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/aspathlists/{objectId}                                                                                 |
| updateAsPathList                               | PUT    | /api/fmc_config/v1/domain/{domainUUID}/object/aspathlists/{objectId}                                                                                 |
| deleteAsPathList                               | DELETE | /api/fmc_config/v1/domain/{domainUUID}/object/aspathlists/{objectId}                                                                                 |
| getAllAzureADRealm                             | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/azureadrealms                                                                                          |
| createAzureADRealm                             | POST   | /api/fmc_config/v1/domain/{domainUUID}/object/azureadrealms                                                                                          |
| getAzureADRealm                                | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/azureadrealms/{objectId}                                                                               |
| updateAzureADRealm                             | PUT    | /api/fmc_config/v1/domain/{domainUUID}/object/azureadrealms/{objectId}                                                                               |
| deleteAzureADRealm                             | DELETE | /api/fmc_config/v1/domain/{domainUUID}/object/azureadrealms/{objectId}                                                                               |
| createDownloadAzureADUsersAndGroups            | POST   | /api/fmc_config/v1/domain/{domainUUID}/object/azureadrealms/{realmId}/download                                                                       |
| getAzureADStatus                               | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/azureadstatuses                                                                                        |
| getAllBFDTemplate                              | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/bfdtemplates                                                                                           |
| createBFDTemplate                              | POST   | /api/fmc_config/v1/domain/{domainUUID}/object/bfdtemplates                                                                                           |
| getBFDTemplate                                 | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/bfdtemplates/{objectId}                                                                                |
| updateBFDTemplate                              | PUT    | /api/fmc_config/v1/domain/{domainUUID}/object/bfdtemplates/{objectId}                                                                                |
| deleteBFDTemplate                              | DELETE | /api/fmc_config/v1/domain/{domainUUID}/object/bfdtemplates/{objectId}                                                                                |
| createDynamicObjectsBulk                       | POST   | /api/fmc_config/v1/domain/{domainUUID}/object/bulkdynamicobjects                                                                                     |
| getAllVpnCertEnrollmentModel                   | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/certenrollments                                                                                        |
| createVpnCertEnrollmentModel                   | POST   | /api/fmc_config/v1/domain/{domainUUID}/object/certenrollments                                                                                        |
| getVpnCertEnrollmentModel                      | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/certenrollments/{objectId}                                                                             |
| updateVpnCertEnrollmentModel                   | PUT    | /api/fmc_config/v1/domain/{domainUUID}/object/certenrollments/{objectId}                                                                             |
| deleteVpnCertEnrollmentModel                   | DELETE | /api/fmc_config/v1/domain/{domainUUID}/object/certenrollments/{objectId}                                                                             |
| getAllCertificateMapModel                      | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/certificatemaps                                                                                        |
| createCertificateMapModel                      | POST   | /api/fmc_config/v1/domain/{domainUUID}/object/certificatemaps                                                                                        |
| getCertificateMapModel                         | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/certificatemaps/{objectId}                                                                             |
| updateCertificateMapModel                      | PUT    | /api/fmc_config/v1/domain/{domainUUID}/object/certificatemaps/{objectId}                                                                             |
| deleteCertificateMapModel                      | DELETE | /api/fmc_config/v1/domain/{domainUUID}/object/certificatemaps/{objectId}                                                                             |
| getCipherSuiteList                             | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/ciphersuitelists                                                                                       |
| createCipherSuiteList                          | POST   | /api/fmc_config/v1/domain/{domainUUID}/object/ciphersuitelists                                                                                       |
| getAllCommunityList                            | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/communitylists                                                                                         |
| getCommunityList                               | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/communitylists/{objectId}                                                                              |
| getAllContinentObject                          | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/continents                                                                                             |
| getContinentObject                             | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/continents/{objectId}                                                                                  |
| getAllCountryObject                            | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/countries                                                                                              |
| getCountryObject                               | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/countries/{objectId}                                                                                   |
| getCustomSIIPListDownload                      | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/customsiiplistdownload/{objectId}                                                                      |
| getAllCustomSIIPList                           | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/customsiiplists                                                                                        |
| createCustomSIIPList                           | POST   | /api/fmc_config/v1/domain/{domainUUID}/object/customsiiplists                                                                                        |
| getCustomSIIPList                              | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/customsiiplists/{objectId}                                                                             |
| updateCustomSIIPList                           | PUT    | /api/fmc_config/v1/domain/{domainUUID}/object/customsiiplists/{objectId}                                                                             |
| deleteCustomSIIPList                           | DELETE | /api/fmc_config/v1/domain/{domainUUID}/object/customsiiplists/{objectId}                                                                             |
| getCustomSIURLListDownload                     | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/customsiurllistdownload/{objectId}                                                                     |
| getAllCustomSIURLList                          | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/customsiurllists                                                                                       |
| createCustomSIURLList                          | POST   | /api/fmc_config/v1/domain/{domainUUID}/object/customsiurllists                                                                                       |
| getCustomSIURLList                             | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/customsiurllists/{objectId}                                                                            |
| updateCustomSIURLList                          | PUT    | /api/fmc_config/v1/domain/{domainUUID}/object/customsiurllists/{objectId}                                                                            |
| deleteCustomSIURLList                          | DELETE | /api/fmc_config/v1/domain/{domainUUID}/object/customsiurllists/{objectId}                                                                            |
| getAllDHCPIPv6Pool                             | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/dhcpipv6pools                                                                                          |
| createDHCPIPv6Pool                             | POST   | /api/fmc_config/v1/domain/{domainUUID}/object/dhcpipv6pools                                                                                          |
| getDHCPIPv6Pool                                | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/dhcpipv6pools/{objectId}                                                                               |
| updateDHCPIPv6Pool                             | PUT    | /api/fmc_config/v1/domain/{domainUUID}/object/dhcpipv6pools/{objectId}                                                                               |
| deleteDHCPIPv6Pool                             | DELETE | /api/fmc_config/v1/domain/{domainUUID}/object/dhcpipv6pools/{objectId}                                                                               |
| getDistinguishedNameGroup                      | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/distinguishednamegroups                                                                                |
| getDistinguishedName                           | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/distinguishednames                                                                                     |
| createDistinguishedName                        | POST   | /api/fmc_config/v1/domain/{domainUUID}/object/distinguishednames                                                                                     |
| getAllDNSServerGroupObject                     | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/dnsservergroups                                                                                        |
| createDNSServerGroupObject                     | POST   | /api/fmc_config/v1/domain/{domainUUID}/object/dnsservergroups                                                                                        |
| getAllDNSServerGroupOverride                   | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/dnsservergroups/{containerUUID}/overrides                                                              |
| getDNSServerGroupOverride                      | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/dnsservergroups/{containerUUID}/overrides/{objectId}                                                   |
| getDNSServerGroupObject                        | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/dnsservergroups/{objectId}                                                                             |
| updateDNSServerGroupObject                     | PUT    | /api/fmc_config/v1/domain/{domainUUID}/object/dnsservergroups/{objectId}                                                                             |
| deleteDNSServerGroupObject                     | DELETE | /api/fmc_config/v1/domain/{domainUUID}/object/dnsservergroups/{objectId}                                                                             |
| createDownloadInternalCA                       | POST   | /api/fmc_config/v1/domain/{domainUUID}/object/downloadinternalca                                                                                     |
| createDynamicObjectMappingsBulk                | POST   | /api/fmc_config/v1/domain/{domainUUID}/object/dynamicobjectmappings                                                                                  |
| deleteMultipleDynamicObjectMappingsBulk        | DELETE | /api/fmc_config/v1/domain/{domainUUID}/object/dynamicobjectmappings                                                                                  |
| getAllDynamicObject                            | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/dynamicobjects                                                                                         |
| createMultipleDynamicObject                    | POST   | /api/fmc_config/v1/domain/{domainUUID}/object/dynamicobjects                                                                                         |
| deleteMultipleDynamicObject                    | DELETE | /api/fmc_config/v1/domain/{domainUUID}/object/dynamicobjects                                                                                         |
| getDynamicObject                               | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/dynamicobjects/{objectId}                                                                              |
| updateDynamicObject                            | PUT    | /api/fmc_config/v1/domain/{domainUUID}/object/dynamicobjects/{objectId}                                                                              |
| deleteDynamicObject                            | DELETE | /api/fmc_config/v1/domain/{domainUUID}/object/dynamicobjects/{objectId}                                                                              |
| getDynamicObjectMappings                       | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/dynamicobjects/{objectId}/mappings                                                                     |
| updateDynamicObjectMappings                    | PUT    | /api/fmc_config/v1/domain/{domainUUID}/object/dynamicobjects/{objectId}/mappings                                                                     |
| getAllEndPointDeviceType                       | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/endpointdevicetypes                                                                                    |
| getEndPointDeviceType                          | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/endpointdevicetypes/{objectId}                                                                         |
| getAllExpandedCommunityList                    | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/expandedcommunitylists                                                                                 |
| createExpandedCommunityList                    | POST   | /api/fmc_config/v1/domain/{domainUUID}/object/expandedcommunitylists                                                                                 |
| getExpandedCommunityList                       | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/expandedcommunitylists/{objectId}                                                                      |
| updateExpandedCommunityList                    | PUT    | /api/fmc_config/v1/domain/{domainUUID}/object/expandedcommunitylists/{objectId}                                                                      |
| deleteExpandedCommunityList                    | DELETE | /api/fmc_config/v1/domain/{domainUUID}/object/expandedcommunitylists/{objectId}                                                                      |
| getAllExtendedAccessListModel                  | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/extendedaccesslists                                                                                    |
| createExtendedAccessListModel                  | POST   | /api/fmc_config/v1/domain/{domainUUID}/object/extendedaccesslists                                                                                    |
| getExtendedAccessListModel                     | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/extendedaccesslists/{objectId}                                                                         |
| updateExtendedAccessListModel                  | PUT    | /api/fmc_config/v1/domain/{domainUUID}/object/extendedaccesslists/{objectId}                                                                         |
| deleteExtendedAccessListModel                  | DELETE | /api/fmc_config/v1/domain/{domainUUID}/object/extendedaccesslists/{objectId}                                                                         |
| getAllExtendedCommunityList                    | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/extendedcommunitylists                                                                                 |
| createExtendedCommunityList                    | POST   | /api/fmc_config/v1/domain/{domainUUID}/object/extendedcommunitylists                                                                                 |
| getAllExtendedCommunityListOverride            | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/extendedcommunitylists/{containerUUID}/overrides                                                       |
| getExtendedCommunityListOverride               | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/extendedcommunitylists/{containerUUID}/overrides/{objectId}                                            |
| getExtendedCommunityList                       | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/extendedcommunitylists/{objectId}                                                                      |
| updateExtendedCommunityList                    | PUT    | /api/fmc_config/v1/domain/{domainUUID}/object/extendedcommunitylists/{objectId}                                                                      |
| deleteExtendedCommunityList                    | DELETE | /api/fmc_config/v1/domain/{domainUUID}/object/extendedcommunitylists/{objectId}                                                                      |
| getExternalCACertificateGroup                  | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/externalcacertificategroups                                                                            |
| getExternalCACertificate                       | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/externalcacertificates                                                                                 |
| createExternalCACertificate                    | POST   | /api/fmc_config/v1/domain/{domainUUID}/object/externalcacertificates                                                                                 |
| getExternalCertificateGroup                    | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/externalcertificategroups                                                                              |
| getExternalCertificate                         | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/externalcertificates                                                                                   |
| createExternalCertificate                      | POST   | /api/fmc_config/v1/domain/{domainUUID}/object/externalcertificates                                                                                   |
| getAllFileCategoryModel                        | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/filecategories                                                                                         |
| getFileCategoryModel                           | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/filecategories/{objectId}                                                                              |
| getAllFileTypeModel                            | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/filetypes                                                                                              |
| getFileTypeModel                               | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/filetypes/{objectId}                                                                                   |
| getAllFQDNObject                               | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/fqdns                                                                                                  |
| createMultipleFQDNObject                       | POST   | /api/fmc_config/v1/domain/{domainUUID}/object/fqdns                                                                                                  |
| deleteMultipleFQDNObject                       | DELETE | /api/fmc_config/v1/domain/{domainUUID}/object/fqdns                                                                                                  |
| getAllFQDNOverride                             | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/fqdns/{containerUUID}/overrides                                                                        |
| getFQDNOverride                                | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/fqdns/{containerUUID}/overrides/{objectId}                                                             |
| getFQDNObject                                  | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/fqdns/{objectId}                                                                                       |
| updateFQDNObject                               | PUT    | /api/fmc_config/v1/domain/{domainUUID}/object/fqdns/{objectId}                                                                                       |
| deleteFQDNObject                               | DELETE | /api/fmc_config/v1/domain/{domainUUID}/object/fqdns/{objectId}                                                                                       |
| getAllGeoLocationObject                        | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/geolocations                                                                                           |
| createGeoLocationObject                        | POST   | /api/fmc_config/v1/domain/{domainUUID}/object/geolocations                                                                                           |
| getGeoLocationObject                           | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/geolocations/{objectId}                                                                                |
| updateGeoLocationObject                        | PUT    | /api/fmc_config/v1/domain/{domainUUID}/object/geolocations/{objectId}                                                                                |
| deleteGeoLocationObject                        | DELETE | /api/fmc_config/v1/domain/{domainUUID}/object/geolocations/{objectId}                                                                                |
| getAllGlobalTimeZone                           | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/globaltimezones                                                                                        |
| getGlobalTimeZone                              | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/globaltimezones/{objectId}                                                                             |
| getAllGroupPolicyModel                         | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/grouppolicies                                                                                          |
| createMultipleGroupPolicyModel                 | POST   | /api/fmc_config/v1/domain/{domainUUID}/object/grouppolicies                                                                                          |
| getGroupPolicyModel                            | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/grouppolicies/{objectId}                                                                               |
| updateGroupPolicyModel                         | PUT    | /api/fmc_config/v1/domain/{domainUUID}/object/grouppolicies/{objectId}                                                                               |
| deleteGroupPolicyModel                         | DELETE | /api/fmc_config/v1/domain/{domainUUID}/object/grouppolicies/{objectId}                                                                               |
| getAllHostObject                               | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/hosts                                                                                                  |
| createMultipleHostObject                       | POST   | /api/fmc_config/v1/domain/{domainUUID}/object/hosts                                                                                                  |
| deleteMultipleHostObject                       | DELETE | /api/fmc_config/v1/domain/{domainUUID}/object/hosts                                                                                                  |
| getAllHostOverride                             | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/hosts/{containerUUID}/overrides                                                                        |
| getHostOverride                                | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/hosts/{containerUUID}/overrides/{objectId}                                                             |
| getHostObject                                  | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/hosts/{objectId}                                                                                       |
| updateHostObject                               | PUT    | /api/fmc_config/v1/domain/{domainUUID}/object/hosts/{objectId}                                                                                       |
| deleteHostObject                               | DELETE | /api/fmc_config/v1/domain/{domainUUID}/object/hosts/{objectId}                                                                                       |
| getAllHostScanPackageObject                    | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/hostscanpackages                                                                                       |
| createHostScanPackageObject                    | POST   | /api/fmc_config/v1/domain/{domainUUID}/object/hostscanpackages                                                                                       |
| getHostScanPackageObject                       | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/hostscanpackages/{objectId}                                                                            |
| updateHostScanPackageObject                    | PUT    | /api/fmc_config/v1/domain/{domainUUID}/object/hostscanpackages/{objectId}                                                                            |
| deleteHostScanPackageObject                    | DELETE | /api/fmc_config/v1/domain/{domainUUID}/object/hostscanpackages/{objectId}                                                                            |
| getAllICMPV4Object                             | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/icmpv4objects                                                                                          |
| createMultipleICMPV4Object                     | POST   | /api/fmc_config/v1/domain/{domainUUID}/object/icmpv4objects                                                                                          |
| deleteMultipleICMPV4Object                     | DELETE | /api/fmc_config/v1/domain/{domainUUID}/object/icmpv4objects                                                                                          |
| getAllICMPV4ObjectOverride                     | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/icmpv4objects/{containerUUID}/overrides                                                                |
| getICMPV4ObjectOverride                        | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/icmpv4objects/{containerUUID}/overrides/{objectId}                                                     |
| getICMPV4Object                                | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/icmpv4objects/{objectId}                                                                               |
| updateICMPV4Object                             | PUT    | /api/fmc_config/v1/domain/{domainUUID}/object/icmpv4objects/{objectId}                                                                               |
| deleteICMPV4Object                             | DELETE | /api/fmc_config/v1/domain/{domainUUID}/object/icmpv4objects/{objectId}                                                                               |
| getAllICMPV6Object                             | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/icmpv6objects                                                                                          |
| createMultipleICMPV6Object                     | POST   | /api/fmc_config/v1/domain/{domainUUID}/object/icmpv6objects                                                                                          |
| deleteMultipleICMPV6Object                     | DELETE | /api/fmc_config/v1/domain/{domainUUID}/object/icmpv6objects                                                                                          |
| getAllICMPV6ObjectOverride                     | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/icmpv6objects/{containerUUID}/overrides                                                                |
| getICMPV6ObjectOverride                        | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/icmpv6objects/{containerUUID}/overrides/{objectId}                                                     |
| getICMPV6Object                                | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/icmpv6objects/{objectId}                                                                               |
| updateICMPV6Object                             | PUT    | /api/fmc_config/v1/domain/{domainUUID}/object/icmpv6objects/{objectId}                                                                               |
| deleteICMPV6Object                             | DELETE | /api/fmc_config/v1/domain/{domainUUID}/object/icmpv6objects/{objectId}                                                                               |
| getAllIKEv1IPsecProposal                       | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/ikev1ipsecproposals                                                                                    |
| createIKEv1IPsecProposal                       | POST   | /api/fmc_config/v1/domain/{domainUUID}/object/ikev1ipsecproposals                                                                                    |
| getIKEv1IPsecProposal                          | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/ikev1ipsecproposals/{objectId}                                                                         |
| updateIKEv1IPsecProposal                       | PUT    | /api/fmc_config/v1/domain/{domainUUID}/object/ikev1ipsecproposals/{objectId}                                                                         |
| deleteIKEv1IPsecProposal                       | DELETE | /api/fmc_config/v1/domain/{domainUUID}/object/ikev1ipsecproposals/{objectId}                                                                         |
| getAllIkev1PolicyObject                        | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/ikev1policies                                                                                          |
| createIkev1PolicyObject                        | POST   | /api/fmc_config/v1/domain/{domainUUID}/object/ikev1policies                                                                                          |
| getIkev1PolicyObject                           | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/ikev1policies/{objectId}                                                                               |
| updateIkev1PolicyObject                        | PUT    | /api/fmc_config/v1/domain/{domainUUID}/object/ikev1policies/{objectId}                                                                               |
| deleteIkev1PolicyObject                        | DELETE | /api/fmc_config/v1/domain/{domainUUID}/object/ikev1policies/{objectId}                                                                               |
| getAllIKEv2IPsecProposal                       | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/ikev2ipsecproposals                                                                                    |
| createIKEv2IPsecProposal                       | POST   | /api/fmc_config/v1/domain/{domainUUID}/object/ikev2ipsecproposals                                                                                    |
| getIKEv2IPsecProposal                          | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/ikev2ipsecproposals/{objectId}                                                                         |
| updateIKEv2IPsecProposal                       | PUT    | /api/fmc_config/v1/domain/{domainUUID}/object/ikev2ipsecproposals/{objectId}                                                                         |
| deleteIKEv2IPsecProposal                       | DELETE | /api/fmc_config/v1/domain/{domainUUID}/object/ikev2ipsecproposals/{objectId}                                                                         |
| getAllIkev2PolicyObject                        | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/ikev2policies                                                                                          |
| createIkev2PolicyObject                        | POST   | /api/fmc_config/v1/domain/{domainUUID}/object/ikev2policies                                                                                          |
| getIkev2PolicyObject                           | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/ikev2policies/{objectId}                                                                               |
| updateIkev2PolicyObject                        | PUT    | /api/fmc_config/v1/domain/{domainUUID}/object/ikev2policies/{objectId}                                                                               |
| deleteIkev2PolicyObject                        | DELETE | /api/fmc_config/v1/domain/{domainUUID}/object/ikev2policies/{objectId}                                                                               |
| getAllInterfaceGroupObject                     | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/interfacegroups                                                                                        |
| createMultipleInterfaceGroupObject             | POST   | /api/fmc_config/v1/domain/{domainUUID}/object/interfacegroups                                                                                        |
| getInterfaceGroupObject                        | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/interfacegroups/{objectId}                                                                             |
| updateInterfaceGroupObject                     | PUT    | /api/fmc_config/v1/domain/{domainUUID}/object/interfacegroups/{objectId}                                                                             |
| deleteInterfaceGroupObject                     | DELETE | /api/fmc_config/v1/domain/{domainUUID}/object/interfacegroups/{objectId}                                                                             |
| getAllInterfaceObject                          | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/interfaceobjects                                                                                       |
| getInterfaceObject                             | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/interfaceobjects/{objectId}                                                                            |
| getAllInternalCA                               | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/internalcas                                                                                            |
| createInternalCA                               | POST   | /api/fmc_config/v1/domain/{domainUUID}/object/internalcas                                                                                            |
| getInternalCA                                  | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/internalcas/{objectId}                                                                                 |
| updateInternalCA                               | PUT    | /api/fmc_config/v1/domain/{domainUUID}/object/internalcas/{objectId}                                                                                 |
| deleteInternalCA                               | DELETE | /api/fmc_config/v1/domain/{domainUUID}/object/internalcas/{objectId}                                                                                 |
| getInternalCertificateGroup                    | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/internalcertgroups                                                                                     |
| getAllInternalCertificate                      | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/internalcertificates                                                                                   |
| createInternalCertificate                      | POST   | /api/fmc_config/v1/domain/{domainUUID}/object/internalcertificates                                                                                   |
| getInternalCertificate                         | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/internalcertificates/{objectId}                                                                        |
| updateInternalCertificate                      | PUT    | /api/fmc_config/v1/domain/{domainUUID}/object/internalcertificates/{objectId}                                                                        |
| deleteInternalCertificate                      | DELETE | /api/fmc_config/v1/domain/{domainUUID}/object/internalcertificates/{objectId}                                                                        |
| getAllSnort3IntrusionRuleGroupsObject          | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/intrusionrulegroups                                                                                    |
| createMultipleSnort3IntrusionRuleGroupsObject  | POST   | /api/fmc_config/v1/domain/{domainUUID}/object/intrusionrulegroups                                                                                    |
| getSnort3IntrusionRuleGroupsObject             | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/intrusionrulegroups/{objectId}                                                                         |
| updateSnort3IntrusionRuleGroupsObject          | PUT    | /api/fmc_config/v1/domain/{domainUUID}/object/intrusionrulegroups/{objectId}                                                                         |
| deleteSnort3IntrusionRuleGroupsObject          | DELETE | /api/fmc_config/v1/domain/{domainUUID}/object/intrusionrulegroups/{objectId}                                                                         |
| getAllSnort3IPSRulesObject                     | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/intrusionrules                                                                                         |
| createMultipleSnort3IPSRulesObject             | POST   | /api/fmc_config/v1/domain/{domainUUID}/object/intrusionrules                                                                                         |
| updateMultipleSnort3IPSRulesObject             | PUT    | /api/fmc_config/v1/domain/{domainUUID}/object/intrusionrules                                                                                         |
| deleteMultipleSnort3IPSRulesObject             | DELETE | /api/fmc_config/v1/domain/{domainUUID}/object/intrusionrules                                                                                         |
| getSnort3IPSRulesObject                        | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/intrusionrules/{objectId}                                                                              |
| updateSnort3IPSRulesObject                     | PUT    | /api/fmc_config/v1/domain/{domainUUID}/object/intrusionrules/{objectId}                                                                              |
| deleteSnort3IPSRulesObject                     | DELETE | /api/fmc_config/v1/domain/{domainUUID}/object/intrusionrules/{objectId}                                                                              |
| createSnort3IPSRulesFileUpload                 | POST   | /api/fmc_config/v1/domain/{domainUUID}/object/intrusionrulesupload                                                                                   |
| getAllIPv4AddressPool                          | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/ipv4addresspools                                                                                       |
| createIPv4AddressPool                          | POST   | /api/fmc_config/v1/domain/{domainUUID}/object/ipv4addresspools                                                                                       |
| getIPv4AddressPoolOverride                     | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/ipv4addresspools/{containerUUID}/overrides                                                             |
| getIPv4AddressPool                             | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/ipv4addresspools/{objectId}                                                                            |
| updateIPv4AddressPool                          | PUT    | /api/fmc_config/v1/domain/{domainUUID}/object/ipv4addresspools/{objectId}                                                                            |
| deleteIPv4AddressPool                          | DELETE | /api/fmc_config/v1/domain/{domainUUID}/object/ipv4addresspools/{objectId}                                                                            |
| getAllIPv4PrefixList                           | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/ipv4prefixlists                                                                                        |
| createIPv4PrefixList                           | POST   | /api/fmc_config/v1/domain/{domainUUID}/object/ipv4prefixlists                                                                                        |
| getIPv4PrefixList                              | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/ipv4prefixlists/{objectId}                                                                             |
| updateIPv4PrefixList                           | PUT    | /api/fmc_config/v1/domain/{domainUUID}/object/ipv4prefixlists/{objectId}                                                                             |
| deleteIPv4PrefixList                           | DELETE | /api/fmc_config/v1/domain/{domainUUID}/object/ipv4prefixlists/{objectId}                                                                             |
| getAllIPv6AddressPool                          | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/ipv6addresspools                                                                                       |
| createIPv6AddressPool                          | POST   | /api/fmc_config/v1/domain/{domainUUID}/object/ipv6addresspools                                                                                       |
| getIPv6AddressPoolOverride                     | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/ipv6addresspools/{containerUUID}/overrides                                                             |
| getIPv6AddressPool                             | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/ipv6addresspools/{objectId}                                                                            |
| updateIPv6AddressPool                          | PUT    | /api/fmc_config/v1/domain/{domainUUID}/object/ipv6addresspools/{objectId}                                                                            |
| deleteIPv6AddressPool                          | DELETE | /api/fmc_config/v1/domain/{domainUUID}/object/ipv6addresspools/{objectId}                                                                            |
| getAllIPv6PrefixList                           | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/ipv6prefixlists                                                                                        |
| createIPv6PrefixList                           | POST   | /api/fmc_config/v1/domain/{domainUUID}/object/ipv6prefixlists                                                                                        |
| getIPv6PrefixList                              | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/ipv6prefixlists/{objectId}                                                                             |
| updateIPv6PrefixList                           | PUT    | /api/fmc_config/v1/domain/{domainUUID}/object/ipv6prefixlists/{objectId}                                                                             |
| deleteIPv6PrefixList                           | DELETE | /api/fmc_config/v1/domain/{domainUUID}/object/ipv6prefixlists/{objectId}                                                                             |
| getAllISESecurityGroupTag                      | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/isesecuritygrouptags                                                                                   |
| getISESecurityGroupTag                         | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/isesecuritygrouptags/{objectId}                                                                        |
| getAllKeyChainObject                           | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/keychains                                                                                              |
| createMultipleKeyChainObject                   | POST   | /api/fmc_config/v1/domain/{domainUUID}/object/keychains                                                                                              |
| getAllKeyChainObjectOverride                   | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/keychains/{containerUUID}/overrides                                                                    |
| getKeyChainObjectOverride                      | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/keychains/{containerUUID}/overrides/{objectId}                                                         |
| getKeyChainObject                              | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/keychains/{objectId}                                                                                   |
| updateKeyChainObject                           | PUT    | /api/fmc_config/v1/domain/{domainUUID}/object/keychains/{objectId}                                                                                   |
| deleteKeyChainObject                           | DELETE | /api/fmc_config/v1/domain/{domainUUID}/object/keychains/{objectId}                                                                                   |
| getAllLocalRealmUser                           | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/localrealmusers                                                                                        |
| createMultipleLocalRealmUser                   | POST   | /api/fmc_config/v1/domain/{domainUUID}/object/localrealmusers                                                                                        |
| getLocalRealmUser                              | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/localrealmusers/{objectId}                                                                             |
| updateLocalRealmUser                           | PUT    | /api/fmc_config/v1/domain/{domainUUID}/object/localrealmusers/{objectId}                                                                             |
| deleteLocalRealmUser                           | DELETE | /api/fmc_config/v1/domain/{domainUUID}/object/localrealmusers/{objectId}                                                                             |
| getAllMacAddressPool                           | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/macaddresspools                                                                                        |
| createMacAddressPool                           | POST   | /api/fmc_config/v1/domain/{domainUUID}/object/macaddresspools                                                                                        |
| getMacAddressPoolOverride                      | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/macaddresspools/{containerUUID}/overrides                                                              |
| getMacAddressPool                              | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/macaddresspools/{objectId}                                                                             |
| updateMacAddressPool                           | PUT    | /api/fmc_config/v1/domain/{domainUUID}/object/macaddresspools/{objectId}                                                                             |
| deleteMacAddressPool                           | DELETE | /api/fmc_config/v1/domain/{domainUUID}/object/macaddresspools/{objectId}                                                                             |
| getNetworkAddress                              | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/networkaddresses                                                                                       |
| getNetworkAddressOverrides                     | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/networkaddressoverrides                                                                                |
| getAllNetworkGroup                             | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/networkgroups                                                                                          |
| createMultipleNetworkGroup                     | POST   | /api/fmc_config/v1/domain/{domainUUID}/object/networkgroups                                                                                          |
| deleteMultipleNetworkGroup                     | DELETE | /api/fmc_config/v1/domain/{domainUUID}/object/networkgroups                                                                                          |
| getAllNetworkGroupOverride                     | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/networkgroups/{containerUUID}/overrides                                                                |
| getNetworkGroupOverride                        | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/networkgroups/{containerUUID}/overrides/{objectId}                                                     |
| getNetworkGroup                                | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/networkgroups/{objectId}                                                                               |
| updateNetworkGroup                             | PUT    | /api/fmc_config/v1/domain/{domainUUID}/object/networkgroups/{objectId}                                                                               |
| deleteNetworkGroup                             | DELETE | /api/fmc_config/v1/domain/{domainUUID}/object/networkgroups/{objectId}                                                                               |
| getAllNetworkObject                            | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/networks                                                                                               |
| createMultipleNetworkObject                    | POST   | /api/fmc_config/v1/domain/{domainUUID}/object/networks                                                                                               |
| deleteMultipleNetworkObject                    | DELETE | /api/fmc_config/v1/domain/{domainUUID}/object/networks                                                                                               |
| getAllNetworkOverride                          | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/networks/{containerUUID}/overrides                                                                     |
| getNetworkObject                               | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/networks/{objectId}                                                                                    |
| updateNetworkObject                            | PUT    | /api/fmc_config/v1/domain/{domainUUID}/object/networks/{objectId}                                                                                    |
| deleteNetworkObject                            | DELETE | /api/fmc_config/v1/domain/{domainUUID}/object/networks/{objectId}                                                                                    |
| getAllNTPServerObject                          | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/ntpservers                                                                                             |
| createNTPServerObject                          | POST   | /api/fmc_config/v1/domain/{domainUUID}/object/ntpservers                                                                                             |
| getNTPServerObject                             | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/ntpservers/{objectId}                                                                                  |
| updateNTPServerObject                          | PUT    | /api/fmc_config/v1/domain/{domainUUID}/object/ntpservers/{objectId}                                                                                  |
| deleteNTPServerObject                          | DELETE | /api/fmc_config/v1/domain/{domainUUID}/object/ntpservers/{objectId}                                                                                  |
| createOverlapWarning                           | POST   | /api/fmc_config/v1/domain/{domainUUID}/object/operational/findoverlaps                                                                               |
| getRealmStatus                                 | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/operational/realmstatuses                                                                              |
| createRealmTest                                | POST   | /api/fmc_config/v1/domain/{domainUUID}/object/operational/testrealms                                                                                 |
| getUmbrellaProtectionPolicy                    | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/operational/umbrellaprotectionpolicies                                                                 |
| createUmbrellaProtectionPolicy                 | POST   | /api/fmc_config/v1/domain/{domainUUID}/object/operational/umbrellaprotectionpolicies                                                                 |
| getObjectUsage                                 | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/operational/usage                                                                                      |
| getAllPolicyList                               | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/policylists                                                                                            |
| createPolicyList                               | POST   | /api/fmc_config/v1/domain/{domainUUID}/object/policylists                                                                                            |
| getPolicyList                                  | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/policylists/{objectId}                                                                                 |
| updatePolicyList                               | PUT    | /api/fmc_config/v1/domain/{domainUUID}/object/policylists/{objectId}                                                                                 |
| deletePolicyList                               | DELETE | /api/fmc_config/v1/domain/{domainUUID}/object/policylists/{objectId}                                                                                 |
| getAllPortObjectGroup                          | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/portobjectgroups                                                                                       |
| createMultiplePortObjectGroup                  | POST   | /api/fmc_config/v1/domain/{domainUUID}/object/portobjectgroups                                                                                       |
| deleteMultiplePortObjectGroup                  | DELETE | /api/fmc_config/v1/domain/{domainUUID}/object/portobjectgroups                                                                                       |
| getAllPortObjectGroupOverride                  | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/portobjectgroups/{containerUUID}/overrides                                                             |
| getPortObjectGroupOverride                     | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/portobjectgroups/{containerUUID}/overrides/{objectId}                                                  |
| getPortObjectGroup                             | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/portobjectgroups/{objectId}                                                                            |
| updatePortObjectGroup                          | PUT    | /api/fmc_config/v1/domain/{domainUUID}/object/portobjectgroups/{objectId}                                                                            |
| deletePortObjectGroup                          | DELETE | /api/fmc_config/v1/domain/{domainUUID}/object/portobjectgroups/{objectId}                                                                            |
| getPortObject                                  | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/ports                                                                                                  |
| getAllProtocolPortObject                       | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/protocolportobjects                                                                                    |
| createMultipleProtocolPortObject               | POST   | /api/fmc_config/v1/domain/{domainUUID}/object/protocolportobjects                                                                                    |
| deleteMultipleProtocolPortObject               | DELETE | /api/fmc_config/v1/domain/{domainUUID}/object/protocolportobjects                                                                                    |
| getAllProtocolPortObjectOverride               | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/protocolportobjects/{containerUUID}/overrides                                                          |
| getProtocolPortObjectOverride                  | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/protocolportobjects/{containerUUID}/overrides/{objectId}                                               |
| getProtocolPortObject                          | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/protocolportobjects/{objectId}                                                                         |
| updateProtocolPortObject                       | PUT    | /api/fmc_config/v1/domain/{domainUUID}/object/protocolportobjects/{objectId}                                                                         |
| deleteProtocolPortObject                       | DELETE | /api/fmc_config/v1/domain/{domainUUID}/object/protocolportobjects/{objectId}                                                                         |
| getAllRadiusServerGroupModel                   | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/radiusservergroups                                                                                     |
| createMultipleRadiusServerGroupModel           | POST   | /api/fmc_config/v1/domain/{domainUUID}/object/radiusservergroups                                                                                     |
| getRadiusServerGroupModel                      | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/radiusservergroups/{objectId}                                                                          |
| updateRadiusServerGroupModel                   | PUT    | /api/fmc_config/v1/domain/{domainUUID}/object/radiusservergroups/{objectId}                                                                          |
| deleteRadiusServerGroupModel                   | DELETE | /api/fmc_config/v1/domain/{domainUUID}/object/radiusservergroups/{objectId}                                                                          |
| getAllRangeObject                              | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/ranges                                                                                                 |
| createMultipleRangeObject                      | POST   | /api/fmc_config/v1/domain/{domainUUID}/object/ranges                                                                                                 |
| deleteMultipleRangeObject                      | DELETE | /api/fmc_config/v1/domain/{domainUUID}/object/ranges                                                                                                 |
| getAllRangeOverride                            | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/ranges/{containerUUID}/overrides                                                                       |
| getRangeOverride                               | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/ranges/{containerUUID}/overrides/{objectId}                                                            |
| getRangeObject                                 | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/ranges/{objectId}                                                                                      |
| updateRangeObject                              | PUT    | /api/fmc_config/v1/domain/{domainUUID}/object/ranges/{objectId}                                                                                      |
| deleteRangeObject                              | DELETE | /api/fmc_config/v1/domain/{domainUUID}/object/ranges/{objectId}                                                                                      |
| getAllRealm                                    | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/realms                                                                                                 |
| createRealm                                    | POST   | /api/fmc_config/v1/domain/{domainUUID}/object/realms                                                                                                 |
| createRealmDownload                            | POST   | /api/fmc_config/v1/domain/{domainUUID}/object/realms/operational/download                                                                            |
| getRealm                                       | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/realms/{objectId}                                                                                      |
| updateRealm                                    | PUT    | /api/fmc_config/v1/domain/{domainUUID}/object/realms/{objectId}                                                                                      |
| deleteRealm                                    | DELETE | /api/fmc_config/v1/domain/{domainUUID}/object/realms/{objectId}                                                                                      |
| getAllRealmUserGroup                           | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/realmusergroups                                                                                        |
| getRealmUserGroup                              | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/realmusergroups/{objectId}                                                                             |
| getAllRealmUser                                | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/realmusers                                                                                             |
| getRealmUser                                   | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/realmusers/{objectId}                                                                                  |
| getAllResourceProfile                          | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/resourceprofiles                                                                                       |
| createResourceProfile                          | POST   | /api/fmc_config/v1/domain/{domainUUID}/object/resourceprofiles                                                                                       |
| getResourceProfile                             | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/resourceprofiles/{objectId}                                                                            |
| updateResourceProfile                          | PUT    | /api/fmc_config/v1/domain/{domainUUID}/object/resourceprofiles/{objectId}                                                                            |
| deleteResourceProfile                          | DELETE | /api/fmc_config/v1/domain/{domainUUID}/object/resourceprofiles/{objectId}                                                                            |
| getAllRouteMap                                 | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/routemaps                                                                                              |
| createRouteMap                                 | POST   | /api/fmc_config/v1/domain/{domainUUID}/object/routemaps                                                                                              |
| getRouteMap                                    | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/routemaps/{objectId}                                                                                   |
| updateRouteMap                                 | PUT    | /api/fmc_config/v1/domain/{domainUUID}/object/routemaps/{objectId}                                                                                   |
| deleteRouteMap                                 | DELETE | /api/fmc_config/v1/domain/{domainUUID}/object/routemaps/{objectId}                                                                                   |
| getAllAzureADUserOrGroup                       | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/samlrealmusersandgroups                                                                                |
| getAllSecureClientCustomizationModel           | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/secureclientcustomizations                                                                             |
| createSecureClientCustomizationModel           | POST   | /api/fmc_config/v1/domain/{domainUUID}/object/secureclientcustomizations                                                                             |
| getSecureClientCustomizationModel              | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/secureclientcustomizations/{objectId}                                                                  |
| updateSecureClientCustomizationModel           | PUT    | /api/fmc_config/v1/domain/{domainUUID}/object/secureclientcustomizations/{objectId}                                                                  |
| deleteSecureClientCustomizationModel           | DELETE | /api/fmc_config/v1/domain/{domainUUID}/object/secureclientcustomizations/{objectId}                                                                  |
| getAllSecurityGroupTag                         | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/securitygrouptags                                                                                      |
| createSecurityGroupTag                         | POST   | /api/fmc_config/v1/domain/{domainUUID}/object/securitygrouptags                                                                                      |
| getSecurityGroupTag                            | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/securitygrouptags/{objectId}                                                                           |
| updateSecurityGroupTag                         | PUT    | /api/fmc_config/v1/domain/{domainUUID}/object/securitygrouptags/{objectId}                                                                           |
| deleteSecurityGroupTag                         | DELETE | /api/fmc_config/v1/domain/{domainUUID}/object/securitygrouptags/{objectId}                                                                           |
| getAllSecurityZoneObject                       | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/securityzones                                                                                          |
| createMultipleSecurityZoneObject               | POST   | /api/fmc_config/v1/domain/{domainUUID}/object/securityzones                                                                                          |
| getSecurityZoneObject                          | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/securityzones/{objectId}                                                                               |
| updateSecurityZoneObject                       | PUT    | /api/fmc_config/v1/domain/{domainUUID}/object/securityzones/{objectId}                                                                               |
| deleteSecurityZoneObject                       | DELETE | /api/fmc_config/v1/domain/{domainUUID}/object/securityzones/{objectId}                                                                               |
| getAllSIDNSFeed                                | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/sidnsfeeds                                                                                             |
| getSIDNSFeed                                   | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/sidnsfeeds/{objectId}                                                                                  |
| getAllSIDNSList                                | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/sidnslists                                                                                             |
| getSIDNSList                                   | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/sidnslists/{objectId}                                                                                  |
| getAllSINetworkFeed                            | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/sinetworkfeeds                                                                                         |
| createSINetworkFeed                            | POST   | /api/fmc_config/v1/domain/{domainUUID}/object/sinetworkfeeds                                                                                         |
| getSINetworkFeed                               | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/sinetworkfeeds/{objectId}                                                                              |
| updateSINetworkFeed                            | PUT    | /api/fmc_config/v1/domain/{domainUUID}/object/sinetworkfeeds/{objectId}                                                                              |
| deleteSINetworkFeed                            | DELETE | /api/fmc_config/v1/domain/{domainUUID}/object/sinetworkfeeds/{objectId}                                                                              |
| getAllSINetworkList                            | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/sinetworklists                                                                                         |
| getSINetworkList                               | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/sinetworklists/{objectId}                                                                              |
| getAllSinkhole                                 | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/sinkholes                                                                                              |
| getSinkhole                                    | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/sinkholes/{objectId}                                                                                   |
| getAllSIURLFeed                                | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/siurlfeeds                                                                                             |
| createSIURLFeed                                | POST   | /api/fmc_config/v1/domain/{domainUUID}/object/siurlfeeds                                                                                             |
| getSIURLFeed                                   | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/siurlfeeds/{objectId}                                                                                  |
| updateSIURLFeed                                | PUT    | /api/fmc_config/v1/domain/{domainUUID}/object/siurlfeeds/{objectId}                                                                                  |
| deleteSIURLFeed                                | DELETE | /api/fmc_config/v1/domain/{domainUUID}/object/siurlfeeds/{objectId}                                                                                  |
| getAllSIURLList                                | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/siurllists                                                                                             |
| createSIURLList                                | POST   | /api/fmc_config/v1/domain/{domainUUID}/object/siurllists                                                                                             |
| getSIURLList                                   | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/siurllists/{objectId}                                                                                  |
| updateSIURLList                                | PUT    | /api/fmc_config/v1/domain/{domainUUID}/object/siurllists/{objectId}                                                                                  |
| deleteSIURLList                                | DELETE | /api/fmc_config/v1/domain/{domainUUID}/object/siurllists/{objectId}                                                                                  |
| getAllSLAMonitorObjectModel                    | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/slamonitors                                                                                            |
| createMultipleSLAMonitorObjectModel            | POST   | /api/fmc_config/v1/domain/{domainUUID}/object/slamonitors                                                                                            |
| getSLAMonitorObjectModel                       | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/slamonitors/{objectId}                                                                                 |
| updateSLAMonitorObjectModel                    | PUT    | /api/fmc_config/v1/domain/{domainUUID}/object/slamonitors/{objectId}                                                                                 |
| deleteSLAMonitorObjectModel                    | DELETE | /api/fmc_config/v1/domain/{domainUUID}/object/slamonitors/{objectId}                                                                                 |
| getAllSSOServer                                | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/ssoservers                                                                                             |
| createMultipleSSOServer                        | POST   | /api/fmc_config/v1/domain/{domainUUID}/object/ssoservers                                                                                             |
| getSSOServerOverride                           | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/ssoservers/{containerUUID}/overrides                                                                   |
| getSSOServer                                   | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/ssoservers/{objectId}                                                                                  |
| updateSSOServer                                | PUT    | /api/fmc_config/v1/domain/{domainUUID}/object/ssoservers/{objectId}                                                                                  |
| deleteSSOServer                                | DELETE | /api/fmc_config/v1/domain/{domainUUID}/object/ssoservers/{objectId}                                                                                  |
| getAllStandardACL                              | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/standardaccesslists                                                                                    |
| createStandardACL                              | POST   | /api/fmc_config/v1/domain/{domainUUID}/object/standardaccesslists                                                                                    |
| getStandardACL                                 | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/standardaccesslists/{objectId}                                                                         |
| updateStandardACL                              | PUT    | /api/fmc_config/v1/domain/{domainUUID}/object/standardaccesslists/{objectId}                                                                         |
| deleteStandardACL                              | DELETE | /api/fmc_config/v1/domain/{domainUUID}/object/standardaccesslists/{objectId}                                                                         |
| getAllStandardCommunityList                    | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/standardcommunitylists                                                                                 |
| createStandardCommunityList                    | POST   | /api/fmc_config/v1/domain/{domainUUID}/object/standardcommunitylists                                                                                 |
| getStandardCommunityList                       | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/standardcommunitylists/{objectId}                                                                      |
| updateStandardCommunityList                    | PUT    | /api/fmc_config/v1/domain/{domainUUID}/object/standardcommunitylists/{objectId}                                                                      |
| deleteStandardCommunityList                    | DELETE | /api/fmc_config/v1/domain/{domainUUID}/object/standardcommunitylists/{objectId}                                                                      |
| createTestAzureADRealm                         | POST   | /api/fmc_config/v1/domain/{domainUUID}/object/testazureadrealms                                                                                      |
| getAllTimeRange                                | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/timeranges                                                                                             |
| createMultipleTimeRange                        | POST   | /api/fmc_config/v1/domain/{domainUUID}/object/timeranges                                                                                             |
| getTimeRange                                   | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/timeranges/{objectId}                                                                                  |
| updateTimeRange                                | PUT    | /api/fmc_config/v1/domain/{domainUUID}/object/timeranges/{objectId}                                                                                  |
| deleteTimeRange                                | DELETE | /api/fmc_config/v1/domain/{domainUUID}/object/timeranges/{objectId}                                                                                  |
| getAllTimeZoneObject                           | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/timezoneobjects                                                                                        |
| createMultipleTimeZoneObject                   | POST   | /api/fmc_config/v1/domain/{domainUUID}/object/timezoneobjects                                                                                        |
| getTimeZoneObjectOverride                      | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/timezoneobjects/{containerUUID}/overrides                                                              |
| getTimeZoneObject                              | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/timezoneobjects/{objectId}                                                                             |
| updateTimeZoneObject                           | PUT    | /api/fmc_config/v1/domain/{domainUUID}/object/timezoneobjects/{objectId}                                                                             |
| deleteTimeZoneObject                           | DELETE | /api/fmc_config/v1/domain/{domainUUID}/object/timezoneobjects/{objectId}                                                                             |
| getAllTunnelTags                               | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/tunneltags                                                                                             |
| createMultipleTunnelTags                       | POST   | /api/fmc_config/v1/domain/{domainUUID}/object/tunneltags                                                                                             |
| getTunnelTags                                  | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/tunneltags/{objectId}                                                                                  |
| updateTunnelTags                               | PUT    | /api/fmc_config/v1/domain/{domainUUID}/object/tunneltags/{objectId}                                                                                  |
| deleteTunnelTags                               | DELETE | /api/fmc_config/v1/domain/{domainUUID}/object/tunneltags/{objectId}                                                                                  |
| getAllURLCategory                              | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/urlcategories                                                                                          |
| getURLCategory                                 | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/urlcategories/{objectId}                                                                               |
| getAllURLGroupObject                           | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/urlgroups                                                                                              |
| createMultipleURLGroupObject                   | POST   | /api/fmc_config/v1/domain/{domainUUID}/object/urlgroups                                                                                              |
| deleteMultipleURLGroupObject                   | DELETE | /api/fmc_config/v1/domain/{domainUUID}/object/urlgroups                                                                                              |
| getAllUrlGroupOverride                         | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/urlgroups/{containerUUID}/overrides                                                                    |
| getUrlGroupOverride                            | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/urlgroups/{containerUUID}/overrides/{objectId}                                                         |
| getURLGroupObject                              | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/urlgroups/{objectId}                                                                                   |
| updateURLGroupObject                           | PUT    | /api/fmc_config/v1/domain/{domainUUID}/object/urlgroups/{objectId}                                                                                   |
| deleteURLGroupObject                           | DELETE | /api/fmc_config/v1/domain/{domainUUID}/object/urlgroups/{objectId}                                                                                   |
| getAllURLObject                                | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/urls                                                                                                   |
| createMultipleURLObject                        | POST   | /api/fmc_config/v1/domain/{domainUUID}/object/urls                                                                                                   |
| deleteMultipleURLObject                        | DELETE | /api/fmc_config/v1/domain/{domainUUID}/object/urls                                                                                                   |
| getAllUrlOverride                              | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/urls/{containerUUID}/overrides                                                                         |
| getUrlOverride                                 | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/urls/{containerUUID}/overrides/{objectId}                                                              |
| getURLObject                                   | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/urls/{objectId}                                                                                        |
| updateURLObject                                | PUT    | /api/fmc_config/v1/domain/{domainUUID}/object/urls/{objectId}                                                                                        |
| deleteURLObject                                | DELETE | /api/fmc_config/v1/domain/{domainUUID}/object/urls/{objectId}                                                                                        |
| createValidateCertFile                         | POST   | /api/fmc_config/v1/domain/{domainUUID}/object/validatecertfile                                                                                       |
| getAllVariable                                 | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/variables                                                                                              |
| createVariable                                 | POST   | /api/fmc_config/v1/domain/{domainUUID}/object/variables                                                                                              |
| getVariable                                    | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/variables/{objectId}                                                                                   |
| updateVariable                                 | PUT    | /api/fmc_config/v1/domain/{domainUUID}/object/variables/{objectId}                                                                                   |
| deleteVariable                                 | DELETE | /api/fmc_config/v1/domain/{domainUUID}/object/variables/{objectId}                                                                                   |
| getAllVariableSet                              | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/variablesets                                                                                           |
| getVariableSet                                 | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/variablesets/{objectId}                                                                                |
| getAllVlanTagGroup                             | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/vlangrouptags                                                                                          |
| createMultipleVlanTagGroup                     | POST   | /api/fmc_config/v1/domain/{domainUUID}/object/vlangrouptags                                                                                          |
| deleteMultipleVlanTagGroup                     | DELETE | /api/fmc_config/v1/domain/{domainUUID}/object/vlangrouptags                                                                                          |
| getAllVlanTagGroupOverride                     | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/vlangrouptags/{containerUUID}/overrides                                                                |
| getVlanTagGroupOverride                        | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/vlangrouptags/{containerUUID}/overrides/{objectId}                                                     |
| getVlanTagGroup                                | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/vlangrouptags/{objectId}                                                                               |
| updateVlanTagGroup                             | PUT    | /api/fmc_config/v1/domain/{domainUUID}/object/vlangrouptags/{objectId}                                                                               |
| deleteVlanTagGroup                             | DELETE | /api/fmc_config/v1/domain/{domainUUID}/object/vlangrouptags/{objectId}                                                                               |
| getAllVlanTag                                  | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/vlantags                                                                                               |
| createMultipleVlanTag                          | POST   | /api/fmc_config/v1/domain/{domainUUID}/object/vlantags                                                                                               |
| deleteMultipleVlanTag                          | DELETE | /api/fmc_config/v1/domain/{domainUUID}/object/vlantags                                                                                               |
| getAllVlanOverride                             | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/vlantags/{containerUUID}/overrides                                                                     |
| getVlanOverride                                | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/vlantags/{containerUUID}/overrides/{objectId}                                                          |
| getVlanTag                                     | GET    | /api/fmc_config/v1/domain/{domainUUID}/object/vlantags/{objectId}                                                                                    |
| updateVlanTag                                  | PUT    | /api/fmc_config/v1/domain/{domainUUID}/object/vlantags/{objectId}                                                                                    |
| deleteVlanTag                                  | DELETE | /api/fmc_config/v1/domain/{domainUUID}/object/vlantags/{objectId}                                                                                    |
| getAllAccessPolicy                             | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/accesspolicies                                                                                         |
| createAccessPolicy                             | POST   | /api/fmc_config/v1/domain/{domainUUID}/policy/accesspolicies                                                                                         |
| getAllAccessRule                               | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/accesspolicies/{containerUUID}/accessrules                                                             |
| createMultipleAccessRule                       | POST   | /api/fmc_config/v1/domain/{domainUUID}/policy/accesspolicies/{containerUUID}/accessrules                                                             |
| updateMultipleAccessRule                       | PUT    | /api/fmc_config/v1/domain/{domainUUID}/policy/accesspolicies/{containerUUID}/accessrules                                                             |
| deleteMultipleAccessRule                       | DELETE | /api/fmc_config/v1/domain/{domainUUID}/policy/accesspolicies/{containerUUID}/accessrules                                                             |
| getAccessRule                                  | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/accesspolicies/{containerUUID}/accessrules/{objectId}                                                  |
| updateAccessRule                               | PUT    | /api/fmc_config/v1/domain/{domainUUID}/policy/accesspolicies/{containerUUID}/accessrules/{objectId}                                                  |
| deleteAccessRule                               | DELETE | /api/fmc_config/v1/domain/{domainUUID}/policy/accesspolicies/{containerUUID}/accessrules/{objectId}                                                  |
| getAllAccessPolicyCategory                     | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/accesspolicies/{containerUUID}/categories                                                              |
| createAccessPolicyCategory                     | POST   | /api/fmc_config/v1/domain/{domainUUID}/policy/accesspolicies/{containerUUID}/categories                                                              |
| getAccessPolicyCategory                        | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/accesspolicies/{containerUUID}/categories/{objectId}                                                   |
| updateAccessPolicyCategory                     | PUT    | /api/fmc_config/v1/domain/{domainUUID}/policy/accesspolicies/{containerUUID}/categories/{objectId}                                                   |
| deleteAccessPolicyCategory                     | DELETE | /api/fmc_config/v1/domain/{domainUUID}/policy/accesspolicies/{containerUUID}/categories/{objectId}                                                   |
| getAllDefaultAction                            | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/accesspolicies/{containerUUID}/defaultactions                                                          |
| getDefaultAction                               | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/accesspolicies/{containerUUID}/defaultactions/{objectId}                                               |
| updateDefaultAction                            | PUT    | /api/fmc_config/v1/domain/{domainUUID}/policy/accesspolicies/{containerUUID}/defaultactions/{objectId}                                               |
| getAllAccessPolicyInheritanceSetting           | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/accesspolicies/{containerUUID}/inheritancesettings                                                     |
| getAccessPolicyInheritanceSetting              | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/accesspolicies/{containerUUID}/inheritancesettings/{objectId}                                          |
| updateAccessPolicyInheritanceSetting           | PUT    | /api/fmc_config/v1/domain/{domainUUID}/policy/accesspolicies/{containerUUID}/inheritancesettings/{objectId}                                          |
| getAllAccessPolicyLoggingSettingModel          | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/accesspolicies/{containerUUID}/loggingsettings                                                         |
| getAccessPolicyLoggingSettingModel             | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/accesspolicies/{containerUUID}/loggingsettings/{objectId}                                              |
| updateAccessPolicyLoggingSettingModel          | PUT    | /api/fmc_config/v1/domain/{domainUUID}/policy/accesspolicies/{containerUUID}/loggingsettings/{objectId}                                              |
| getHitCount                                    | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/accesspolicies/{containerUUID}/operational/hitcounts                                                   |
| updateHitCount                                 | PUT    | /api/fmc_config/v1/domain/{domainUUID}/policy/accesspolicies/{containerUUID}/operational/hitcounts                                                   |
| deleteHitCount                                 | DELETE | /api/fmc_config/v1/domain/{domainUUID}/policy/accesspolicies/{containerUUID}/operational/hitcounts                                                   |
| getAllAccessPolicySecurityIntelligencePolicy   | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/accesspolicies/{containerUUID}/securityintelligencepolicies                                            |
| getAccessPolicySecurityIntelligencePolicy      | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/accesspolicies/{containerUUID}/securityintelligencepolicies/{objectId}                                 |
| getAccessPolicy                                | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/accesspolicies/{objectId}                                                                              |
| updateAccessPolicy                             | PUT    | /api/fmc_config/v1/domain/{domainUUID}/policy/accesspolicies/{objectId}                                                                              |
| deleteAccessPolicy                             | DELETE | /api/fmc_config/v1/domain/{domainUUID}/policy/accesspolicies/{objectId}                                                                              |
| getAllChassisPlatformSettingsPolicy            | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/chassisplatformsettingspolicies                                                                        |
| createChassisPlatformSettingsPolicy            | POST   | /api/fmc_config/v1/domain/{domainUUID}/policy/chassisplatformsettingspolicies                                                                        |
| getAllChassisAccessListSetting                 | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/chassisplatformsettingspolicies/{containerUUID}/accesslistsettings                                     |
| getChassisAccessListSetting                    | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/chassisplatformsettingspolicies/{containerUUID}/accesslistsettings/{objectId}                          |
| updateChassisAccessListSetting                 | PUT    | /api/fmc_config/v1/domain/{domainUUID}/policy/chassisplatformsettingspolicies/{containerUUID}/accesslistsettings/{objectId}                          |
| getAllDNSSettings                              | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/chassisplatformsettingspolicies/{containerUUID}/dnssettings                                            |
| getDNSSettings                                 | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/chassisplatformsettingspolicies/{containerUUID}/dnssettings/{objectId}                                 |
| updateDNSSettings                              | PUT    | /api/fmc_config/v1/domain/{domainUUID}/policy/chassisplatformsettingspolicies/{containerUUID}/dnssettings/{objectId}                                 |
| getAllSshClientSetting                         | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/chassisplatformsettingspolicies/{containerUUID}/sshclientsettings                                      |
| getSshClientSetting                            | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/chassisplatformsettingspolicies/{containerUUID}/sshclientsettings/{objectId}                           |
| updateSshClientSetting                         | PUT    | /api/fmc_config/v1/domain/{domainUUID}/policy/chassisplatformsettingspolicies/{containerUUID}/sshclientsettings/{objectId}                           |
| getAllSshServerSetting                         | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/chassisplatformsettingspolicies/{containerUUID}/sshserversettings                                      |
| getSshServerSetting                            | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/chassisplatformsettingspolicies/{containerUUID}/sshserversettings/{objectId}                           |
| updateSshServerSetting                         | PUT    | /api/fmc_config/v1/domain/{domainUUID}/policy/chassisplatformsettingspolicies/{containerUUID}/sshserversettings/{objectId}                           |
| getAllChassisSyslogSetting                     | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/chassisplatformsettingspolicies/{containerUUID}/syslogsettings                                         |
| getChassisSyslogSetting                        | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/chassisplatformsettingspolicies/{containerUUID}/syslogsettings/{objectId}                              |
| updateChassisSyslogSetting                     | PUT    | /api/fmc_config/v1/domain/{domainUUID}/policy/chassisplatformsettingspolicies/{containerUUID}/syslogsettings/{objectId}                              |
| getAllChassisTimeSynchronizationSetting        | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/chassisplatformsettingspolicies/{containerUUID}/timesynchronizationsettings                            |
| getChassisTimeSynchronizationSetting           | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/chassisplatformsettingspolicies/{containerUUID}/timesynchronizationsettings/{objectId}                 |
| updateChassisTimeSynchronizationSetting        | PUT    | /api/fmc_config/v1/domain/{domainUUID}/policy/chassisplatformsettingspolicies/{containerUUID}/timesynchronizationsettings/{objectId}                 |
| getAllChassisTimeZoneSetting                   | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/chassisplatformsettingspolicies/{containerUUID}/timezonesettings                                       |
| getChassisTimeZoneSetting                      | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/chassisplatformsettingspolicies/{containerUUID}/timezonesettings/{objectId}                            |
| updateChassisTimeZoneSetting                   | PUT    | /api/fmc_config/v1/domain/{domainUUID}/policy/chassisplatformsettingspolicies/{containerUUID}/timezonesettings/{objectId}                            |
| getChassisPlatformSettingsPolicy               | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/chassisplatformsettingspolicies/{objectId}                                                             |
| updateChassisPlatformSettingsPolicy            | PUT    | /api/fmc_config/v1/domain/{domainUUID}/policy/chassisplatformsettingspolicies/{objectId}                                                             |
| deleteChassisPlatformSettingsPolicy            | DELETE | /api/fmc_config/v1/domain/{domainUUID}/policy/chassisplatformsettingspolicies/{objectId}                                                             |
| getAllDecryptionPolicy                         | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/decryptionpolicies                                                                                     |
| createDecryptionPolicy                         | POST   | /api/fmc_config/v1/domain/{domainUUID}/policy/decryptionpolicies                                                                                     |
| getAllDecryptionPolicyRule                     | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/decryptionpolicies/{containerUUID}/decryptionpolicyrules                                               |
| createMultipleDecryptionPolicyRule             | POST   | /api/fmc_config/v1/domain/{domainUUID}/policy/decryptionpolicies/{containerUUID}/decryptionpolicyrules                                               |
| getDecryptionPolicyRule                        | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/decryptionpolicies/{containerUUID}/decryptionpolicyrules/{objectId}                                    |
| updateDecryptionPolicyRule                     | PUT    | /api/fmc_config/v1/domain/{domainUUID}/policy/decryptionpolicies/{containerUUID}/decryptionpolicyrules/{objectId}                                    |
| deleteDecryptionPolicyRule                     | DELETE | /api/fmc_config/v1/domain/{domainUUID}/policy/decryptionpolicies/{containerUUID}/decryptionpolicyrules/{objectId}                                    |
| getDecryptionPolicy                            | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/decryptionpolicies/{objectId}                                                                          |
| updateDecryptionPolicy                         | PUT    | /api/fmc_config/v1/domain/{domainUUID}/policy/decryptionpolicies/{objectId}                                                                          |
| deleteDecryptionPolicy                         | DELETE | /api/fmc_config/v1/domain/{domainUUID}/policy/decryptionpolicies/{objectId}                                                                          |
| getAllDNSPolicy                                | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/dnspolicies                                                                                            |
| getAllowDNSRule                                | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/dnspolicies/{containerUUID}/allowdnsrules                                                              |
| getBlockDNSRule                                | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/dnspolicies/{containerUUID}/blockdnsrules                                                              |
| getDNSPolicy                                   | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/dnspolicies/{objectId}                                                                                 |
| getAllDynamicAccessPolicy                      | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/dynamicaccesspolicies                                                                                  |
| createDynamicAccessPolicy                      | POST   | /api/fmc_config/v1/domain/{domainUUID}/policy/dynamicaccesspolicies                                                                                  |
| getDynamicAccessPolicy                         | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/dynamicaccesspolicies/{objectId}                                                                       |
| updateDynamicAccessPolicy                      | PUT    | /api/fmc_config/v1/domain/{domainUUID}/policy/dynamicaccesspolicies/{objectId}                                                                       |
| deleteDynamicAccessPolicy                      | DELETE | /api/fmc_config/v1/domain/{domainUUID}/policy/dynamicaccesspolicies/{objectId}                                                                       |
| getAllFilePolicy                               | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/filepolicies                                                                                           |
| createFilePolicy                               | POST   | /api/fmc_config/v1/domain/{domainUUID}/policy/filepolicies                                                                                           |
| getAllFileRuleModel                            | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/filepolicies/{containerUUID}/filerules                                                                 |
| createFileRuleModel                            | POST   | /api/fmc_config/v1/domain/{domainUUID}/policy/filepolicies/{containerUUID}/filerules                                                                 |
| getFileRuleModel                               | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/filepolicies/{containerUUID}/filerules/{objectId}                                                      |
| updateFileRuleModel                            | PUT    | /api/fmc_config/v1/domain/{domainUUID}/policy/filepolicies/{containerUUID}/filerules/{objectId}                                                      |
| deleteFileRuleModel                            | DELETE | /api/fmc_config/v1/domain/{domainUUID}/policy/filepolicies/{containerUUID}/filerules/{objectId}                                                      |
| getFilePolicy                                  | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/filepolicies/{objectId}                                                                                |
| updateFilePolicy                               | PUT    | /api/fmc_config/v1/domain/{domainUUID}/policy/filepolicies/{objectId}                                                                                |
| deleteFilePolicy                               | DELETE | /api/fmc_config/v1/domain/{domainUUID}/policy/filepolicies/{objectId}                                                                                |
| getAllFlexConfig                               | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/flexconfigpolicies                                                                                     |
| createFlexConfig                               | POST   | /api/fmc_config/v1/domain/{domainUUID}/policy/flexconfigpolicies                                                                                     |
| createFlexConfigMigration                      | POST   | /api/fmc_config/v1/domain/{domainUUID}/policy/flexconfigpolicies/{containerUUID}/migrate                                                             |
| getFlexConfig                                  | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/flexconfigpolicies/{objectId}                                                                          |
| getAllFTDNatPolicy                             | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/ftdnatpolicies                                                                                         |
| createFTDNatPolicy                             | POST   | /api/fmc_config/v1/domain/{domainUUID}/policy/ftdnatpolicies                                                                                         |
| getAllFTDAutoNatRule                           | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/ftdnatpolicies/{containerUUID}/autonatrules                                                            |
| createMultipleFTDAutoNatRule                   | POST   | /api/fmc_config/v1/domain/{domainUUID}/policy/ftdnatpolicies/{containerUUID}/autonatrules                                                            |
| updateMultipleFTDAutoNatRule                   | PUT    | /api/fmc_config/v1/domain/{domainUUID}/policy/ftdnatpolicies/{containerUUID}/autonatrules                                                            |
| deleteMultipleFTDAutoNatRule                   | DELETE | /api/fmc_config/v1/domain/{domainUUID}/policy/ftdnatpolicies/{containerUUID}/autonatrules                                                            |
| getFTDAutoNatRule                              | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/ftdnatpolicies/{containerUUID}/autonatrules/{objectId}                                                 |
| updateFTDAutoNatRule                           | PUT    | /api/fmc_config/v1/domain/{domainUUID}/policy/ftdnatpolicies/{containerUUID}/autonatrules/{objectId}                                                 |
| deleteFTDAutoNatRule                           | DELETE | /api/fmc_config/v1/domain/{domainUUID}/policy/ftdnatpolicies/{containerUUID}/autonatrules/{objectId}                                                 |
| getAllFTDManualNatRule                         | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/ftdnatpolicies/{containerUUID}/manualnatrules                                                          |
| createMultipleFTDManualNatRule                 | POST   | /api/fmc_config/v1/domain/{domainUUID}/policy/ftdnatpolicies/{containerUUID}/manualnatrules                                                          |
| updateMultipleFTDManualNatRule                 | PUT    | /api/fmc_config/v1/domain/{domainUUID}/policy/ftdnatpolicies/{containerUUID}/manualnatrules                                                          |
| deleteMultipleFTDManualNatRule                 | DELETE | /api/fmc_config/v1/domain/{domainUUID}/policy/ftdnatpolicies/{containerUUID}/manualnatrules                                                          |
| getFTDManualNatRule                            | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/ftdnatpolicies/{containerUUID}/manualnatrules/{objectId}                                               |
| updateFTDManualNatRule                         | PUT    | /api/fmc_config/v1/domain/{domainUUID}/policy/ftdnatpolicies/{containerUUID}/manualnatrules/{objectId}                                               |
| deleteFTDManualNatRule                         | DELETE | /api/fmc_config/v1/domain/{domainUUID}/policy/ftdnatpolicies/{containerUUID}/manualnatrules/{objectId}                                               |
| getAllFTDNatRule                               | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/ftdnatpolicies/{containerUUID}/natrules                                                                |
| deleteMultipleFTDNatRule                       | DELETE | /api/fmc_config/v1/domain/{domainUUID}/policy/ftdnatpolicies/{containerUUID}/natrules                                                                |
| getFTDNatRule                                  | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/ftdnatpolicies/{containerUUID}/natrules/{objectId}                                                     |
| getFTDNatPolicy                                | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/ftdnatpolicies/{objectId}                                                                              |
| updateFTDNatPolicy                             | PUT    | /api/fmc_config/v1/domain/{domainUUID}/policy/ftdnatpolicies/{objectId}                                                                              |
| deleteFTDNatPolicy                             | DELETE | /api/fmc_config/v1/domain/{domainUUID}/policy/ftdnatpolicies/{objectId}                                                                              |
| getAllFTDPlatformSettingsPolicy                | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/ftdplatformsettingspolicies                                                                            |
| createFTDPlatformSettingsPolicy                | POST   | /api/fmc_config/v1/domain/{domainUUID}/policy/ftdplatformsettingspolicies                                                                            |
| getAllFTDHttpAccessSettingsPolicy              | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/ftdplatformsettingspolicies/{containerUUID}/httpaccesssettings                                         |
| getFTDHttpAccessSettingsPolicy                 | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/ftdplatformsettingspolicies/{containerUUID}/httpaccesssettings/{objectId}                              |
| updateFTDHttpAccessSettingsPolicy              | PUT    | /api/fmc_config/v1/domain/{domainUUID}/policy/ftdplatformsettingspolicies/{containerUUID}/httpaccesssettings/{objectId}                              |
| getAllNetFlowPolicy                            | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/ftdplatformsettingspolicies/{containerUUID}/netflowpolicies                                            |
| getNetFlowPolicy                               | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/ftdplatformsettingspolicies/{containerUUID}/netflowpolicies/{objectId}                                 |
| updateNetFlowPolicy                            | PUT    | /api/fmc_config/v1/domain/{domainUUID}/policy/ftdplatformsettingspolicies/{containerUUID}/netflowpolicies/{objectId}                                 |
| getAllSNMPSettingsPolicy                       | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/ftdplatformsettingspolicies/{containerUUID}/snmpsettings                                               |
| getSNMPSettingsPolicy                          | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/ftdplatformsettingspolicies/{containerUUID}/snmpsettings/{objectId}                                    |
| updateSNMPSettingsPolicy                       | PUT    | /api/fmc_config/v1/domain/{domainUUID}/policy/ftdplatformsettingspolicies/{containerUUID}/snmpsettings/{objectId}                                    |
| getFTDPlatformSettingsPolicy                   | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/ftdplatformsettingspolicies/{objectId}                                                                 |
| updateFTDPlatformSettingsPolicy                | PUT    | /api/fmc_config/v1/domain/{domainUUID}/policy/ftdplatformsettingspolicies/{objectId}                                                                 |
| deleteFTDPlatformSettingsPolicy                | DELETE | /api/fmc_config/v1/domain/{domainUUID}/policy/ftdplatformsettingspolicies/{objectId}                                                                 |
| getAllFTDS2SVpnModel                           | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/ftds2svpns                                                                                             |
| createFTDS2SVpnModel                           | POST   | /api/fmc_config/v1/domain/{domainUUID}/policy/ftds2svpns                                                                                             |
| getAllVpnAdvancedSettings                      | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/ftds2svpns/{containerUUID}/advancedsettings                                                            |
| getVpnAdvancedSettings                         | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/ftds2svpns/{containerUUID}/advancedsettings/{objectId}                                                 |
| updateVpnAdvancedSettings                      | PUT    | /api/fmc_config/v1/domain/{domainUUID}/policy/ftds2svpns/{containerUUID}/advancedsettings/{objectId}                                                 |
| getAllVpnEndpoint                              | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/ftds2svpns/{containerUUID}/endpoints                                                                   |
| createVpnEndpoint                              | POST   | /api/fmc_config/v1/domain/{domainUUID}/policy/ftds2svpns/{containerUUID}/endpoints                                                                   |
| getVpnEndpoint                                 | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/ftds2svpns/{containerUUID}/endpoints/{objectId}                                                        |
| updateVpnEndpoint                              | PUT    | /api/fmc_config/v1/domain/{domainUUID}/policy/ftds2svpns/{containerUUID}/endpoints/{objectId}                                                        |
| deleteVpnEndpoint                              | DELETE | /api/fmc_config/v1/domain/{domainUUID}/policy/ftds2svpns/{containerUUID}/endpoints/{objectId}                                                        |
| getAllVpnIkeSettings                           | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/ftds2svpns/{containerUUID}/ikesettings                                                                 |
| getVpnIkeSettings                              | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/ftds2svpns/{containerUUID}/ikesettings/{objectId}                                                      |
| updateVpnIkeSettings                           | PUT    | /api/fmc_config/v1/domain/{domainUUID}/policy/ftds2svpns/{containerUUID}/ikesettings/{objectId}                                                      |
| getAllVpnIPSecSettings                         | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/ftds2svpns/{containerUUID}/ipsecsettings                                                               |
| getVpnIPSecSettings                            | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/ftds2svpns/{containerUUID}/ipsecsettings/{objectId}                                                    |
| updateVpnIPSecSettings                         | PUT    | /api/fmc_config/v1/domain/{domainUUID}/policy/ftds2svpns/{containerUUID}/ipsecsettings/{objectId}                                                    |
| getFTDS2SVpnModel                              | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/ftds2svpns/{objectId}                                                                                  |
| updateFTDS2SVpnModel                           | PUT    | /api/fmc_config/v1/domain/{domainUUID}/policy/ftds2svpns/{objectId}                                                                                  |
| deleteFTDS2SVpnModel                           | DELETE | /api/fmc_config/v1/domain/{domainUUID}/policy/ftds2svpns/{objectId}                                                                                  |
| getAllHealthPolicy                             | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/healthpolicies                                                                                         |
| createHealthPolicy                             | POST   | /api/fmc_config/v1/domain/{domainUUID}/policy/healthpolicies                                                                                         |
| getHealthPolicy                                | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/healthpolicies/{objectId}                                                                              |
| updateHealthPolicy                             | PUT    | /api/fmc_config/v1/domain/{domainUUID}/policy/healthpolicies/{objectId}                                                                              |
| deleteHealthPolicy                             | DELETE | /api/fmc_config/v1/domain/{domainUUID}/policy/healthpolicies/{objectId}                                                                              |
| getAllIdentityPolicy                           | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/identitypolicies                                                                                       |
| getIdentityPolicy                              | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/identitypolicies/{objectId}                                                                            |
| getAllIntrusionPolicy                          | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/intrusionpolicies                                                                                      |
| createIntrusionPolicy                          | POST   | /api/fmc_config/v1/domain/{domainUUID}/policy/intrusionpolicies                                                                                      |
| getAllSnort3IntrusionRuleGroups                | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/intrusionpolicies/{containerUUID}/intrusionrulegroups                                                  |
| updateMultipleSnort3IntrusionRuleGroups        | PUT    | /api/fmc_config/v1/domain/{domainUUID}/policy/intrusionpolicies/{containerUUID}/intrusionrulegroups                                                  |
| getSnort3IntrusionRuleGroups                   | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/intrusionpolicies/{containerUUID}/intrusionrulegroups/{objectId}                                       |
| updateSnort3IntrusionRuleGroups                | PUT    | /api/fmc_config/v1/domain/{domainUUID}/policy/intrusionpolicies/{containerUUID}/intrusionrulegroups/{objectId}                                       |
| getAllSnort3IPSRules                           | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/intrusionpolicies/{containerUUID}/intrusionrules                                                       |
| updateMultipleSnort3IPSRules                   | PUT    | /api/fmc_config/v1/domain/{domainUUID}/policy/intrusionpolicies/{containerUUID}/intrusionrules                                                       |
| getSnort3IPSRules                              | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/intrusionpolicies/{containerUUID}/intrusionrules/{objectId}                                            |
| updateSnort3IPSRules                           | PUT    | /api/fmc_config/v1/domain/{domainUUID}/policy/intrusionpolicies/{containerUUID}/intrusionrules/{objectId}                                            |
| getIntrusionPolicy                             | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/intrusionpolicies/{objectId}                                                                           |
| updateIntrusionPolicy                          | PUT    | /api/fmc_config/v1/domain/{domainUUID}/policy/intrusionpolicies/{objectId}                                                                           |
| deleteIntrusionPolicy                          | DELETE | /api/fmc_config/v1/domain/{domainUUID}/policy/intrusionpolicies/{objectId}                                                                           |
| getVPNNatExemptModel                           | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/natexemptrules/{deviceId}                                                                              |
| getAllSnort3NetworkAnalysisPolicy              | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/networkanalysispolicies                                                                                |
| createSnort3NetworkAnalysisPolicy              | POST   | /api/fmc_config/v1/domain/{domainUUID}/policy/networkanalysispolicies                                                                                |
| getInspectorConfig                             | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/networkanalysispolicies/{containerUUID}/inspectorconfigs                                               |
| getInspectorOverrideConfig                     | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/networkanalysispolicies/{containerUUID}/inspectoroverrideconfigs                                       |
| updateInspectorOverrideConfig                  | PUT    | /api/fmc_config/v1/domain/{domainUUID}/policy/networkanalysispolicies/{containerUUID}/inspectoroverrideconfigs                                       |
| getSnort3NetworkAnalysisPolicy                 | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/networkanalysispolicies/{objectId}                                                                     |
| updateSnort3NetworkAnalysisPolicy              | PUT    | /api/fmc_config/v1/domain/{domainUUID}/policy/networkanalysispolicies/{objectId}                                                                     |
| deleteSnort3NetworkAnalysisPolicy              | DELETE | /api/fmc_config/v1/domain/{domainUUID}/policy/networkanalysispolicies/{objectId}                                                                     |
| getPolicyLock                                  | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/operational/policylocks                                                                                |
| createPolicyLock                               | POST   | /api/fmc_config/v1/domain/{domainUUID}/policy/operational/policylocks                                                                                |
| getAllPrefilterPolicy                          | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/prefilterpolicies                                                                                      |
| createPrefilterPolicy                          | POST   | /api/fmc_config/v1/domain/{domainUUID}/policy/prefilterpolicies                                                                                      |
| getAllPrefilterDefaultAction                   | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/prefilterpolicies/{containerUUID}/defaultactions                                                       |
| getPrefilterDefaultAction                      | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/prefilterpolicies/{containerUUID}/defaultactions/{objectId}                                            |
| updatePrefilterDefaultAction                   | PUT    | /api/fmc_config/v1/domain/{domainUUID}/policy/prefilterpolicies/{containerUUID}/defaultactions/{objectId}                                            |
| getPrefilterHitCount                           | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/prefilterpolicies/{containerUUID}/operational/hitcounts                                                |
| updatePrefilterHitCount                        | PUT    | /api/fmc_config/v1/domain/{domainUUID}/policy/prefilterpolicies/{containerUUID}/operational/hitcounts                                                |
| deletePrefilterHitCount                        | DELETE | /api/fmc_config/v1/domain/{domainUUID}/policy/prefilterpolicies/{containerUUID}/operational/hitcounts                                                |
| getAllPrefilterRule                            | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/prefilterpolicies/{containerUUID}/prefilterrules                                                       |
| createMultiplePrefilterRule                    | POST   | /api/fmc_config/v1/domain/{domainUUID}/policy/prefilterpolicies/{containerUUID}/prefilterrules                                                       |
| updateMultiplePrefilterRule                    | PUT    | /api/fmc_config/v1/domain/{domainUUID}/policy/prefilterpolicies/{containerUUID}/prefilterrules                                                       |
| deleteMultiplePrefilterRule                    | DELETE | /api/fmc_config/v1/domain/{domainUUID}/policy/prefilterpolicies/{containerUUID}/prefilterrules                                                       |
| getPrefilterRule                               | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/prefilterpolicies/{containerUUID}/prefilterrules/{objectId}                                            |
| updatePrefilterRule                            | PUT    | /api/fmc_config/v1/domain/{domainUUID}/policy/prefilterpolicies/{containerUUID}/prefilterrules/{objectId}                                            |
| deletePrefilterRule                            | DELETE | /api/fmc_config/v1/domain/{domainUUID}/policy/prefilterpolicies/{containerUUID}/prefilterrules/{objectId}                                            |
| getPrefilterPolicy                             | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/prefilterpolicies/{objectId}                                                                           |
| updatePrefilterPolicy                          | PUT    | /api/fmc_config/v1/domain/{domainUUID}/policy/prefilterpolicies/{objectId}                                                                           |
| deletePrefilterPolicy                          | DELETE | /api/fmc_config/v1/domain/{domainUUID}/policy/prefilterpolicies/{objectId}                                                                           |
| getAllFTDRAVpnModel                            | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/ravpns                                                                                                 |
| createFTDRAVpnModel                            | POST   | /api/fmc_config/v1/domain/{domainUUID}/policy/ravpns                                                                                                 |
| getAllFTDRAVpnAddressAssignmentSetting         | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/ravpns/{containerUUID}/addressassignmentsettings                                                       |
| getFTDRAVpnAddressAssignmentSetting            | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/ravpns/{containerUUID}/addressassignmentsettings/{objectId}                                            |
| updateFTDRAVpnAddressAssignmentSetting         | PUT    | /api/fmc_config/v1/domain/{domainUUID}/policy/ravpns/{containerUUID}/addressassignmentsettings/{objectId}                                            |
| getFTDRAVpnCertificateMapSettings              | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/ravpns/{containerUUID}/certificatemapsettings/{objectId}                                               |
| updateFTDRAVpnCertificateMapSettings           | PUT    | /api/fmc_config/v1/domain/{domainUUID}/policy/ravpns/{containerUUID}/certificatemapsettings/{objectId}                                               |
| getAllFTDRAVpnConnectionProfileModel           | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/ravpns/{containerUUID}/connectionprofiles                                                              |
| createFTDRAVpnConnectionProfileModel           | POST   | /api/fmc_config/v1/domain/{domainUUID}/policy/ravpns/{containerUUID}/connectionprofiles                                                              |
| getFTDRAVpnConnectionProfileModel              | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/ravpns/{containerUUID}/connectionprofiles/{objectId}                                                   |
| updateFTDRAVpnConnectionProfileModel           | PUT    | /api/fmc_config/v1/domain/{domainUUID}/policy/ravpns/{containerUUID}/connectionprofiles/{objectId}                                                   |
| deleteFTDRAVpnConnectionProfileModel           | DELETE | /api/fmc_config/v1/domain/{domainUUID}/policy/ravpns/{containerUUID}/connectionprofiles/{objectId}                                                   |
| getAllFTDRAVpnIPSecIKEv2AdvanceSettingsModel   | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/ravpns/{containerUUID}/ipsecadvancedsettings                                                           |
| getFTDRAVpnIPSecIKEv2AdvanceSettingsModel      | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/ravpns/{containerUUID}/ipsecadvancedsettings/{objectId}                                                |
| updateFTDRAVpnIPSecIKEv2AdvanceSettingsModel   | PUT    | /api/fmc_config/v1/domain/{domainUUID}/policy/ravpns/{containerUUID}/ipsecadvancedsettings/{objectId}                                                |
| getAllFTDRAVpnIPSecCryptoMapModel              | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/ravpns/{containerUUID}/ipseccryptomaps                                                                 |
| getFTDRAVpnIPSecCryptoMapModel                 | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/ravpns/{containerUUID}/ipseccryptomaps/{objectId}                                                      |
| updateFTDRAVpnIPSecCryptoMapModel              | PUT    | /api/fmc_config/v1/domain/{domainUUID}/policy/ravpns/{containerUUID}/ipseccryptomaps/{objectId}                                                      |
| getAllFTDRAVpnLDAPAttributeModel               | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/ravpns/{containerUUID}/ldapattributemaps                                                               |
| getFTDRAVpnLDAPAttributeModel                  | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/ravpns/{containerUUID}/ldapattributemaps/{objectId}                                                    |
| updateFTDRAVpnLDAPAttributeModel               | PUT    | /api/fmc_config/v1/domain/{domainUUID}/policy/ravpns/{containerUUID}/ldapattributemaps/{objectId}                                                    |
| getAllFTDRAVpnLoadBalanceSetting               | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/ravpns/{containerUUID}/loadbalancesettings                                                             |
| getFTDRAVpnLoadBalanceSetting                  | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/ravpns/{containerUUID}/loadbalancesettings/{objectId}                                                  |
| updateFTDRAVpnLoadBalanceSetting               | PUT    | /api/fmc_config/v1/domain/{domainUUID}/policy/ravpns/{containerUUID}/loadbalancesettings/{objectId}                                                  |
| getAllFTDRAVpnSecureClientCustomizationSetting | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/ravpns/{containerUUID}/secureclientcustomizationsettings                                               |
| getFTDRAVpnSecureClientCustomizationSetting    | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/ravpns/{containerUUID}/secureclientcustomizationsettings/{objectId}                                    |
| updateFTDRAVpnSecureClientCustomizationSetting | PUT    | /api/fmc_config/v1/domain/{domainUUID}/policy/ravpns/{containerUUID}/secureclientcustomizationsettings/{objectId}                                    |
| getFTDRAVpnModel                               | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/ravpns/{objectId}                                                                                      |
| updateFTDRAVpnModel                            | PUT    | /api/fmc_config/v1/domain/{domainUUID}/policy/ravpns/{objectId}                                                                                      |
| deleteFTDRAVpnModel                            | DELETE | /api/fmc_config/v1/domain/{domainUUID}/policy/ravpns/{objectId}                                                                                      |
| getS2SVpnSummaryModel                          | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/s2svpnsummaries                                                                                        |
| getAllSNMPConfig                               | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/snmpalerts                                                                                             |
| getSNMPConfig                                  | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/snmpalerts/{objectId}                                                                                  |
| getAllSyslogConfig                             | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/syslogalerts                                                                                           |
| getSyslogConfig                                | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/syslogalerts/{objectId}                                                                                |
| getAllUmbrellaDNSPolicy                        | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/umbrelladnspolicies                                                                                    |
| createUmbrellaDNSPolicy                        | POST   | /api/fmc_config/v1/domain/{domainUUID}/policy/umbrelladnspolicies                                                                                    |
| getAllUmbrellaDNSRule                          | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/umbrelladnspolicies/{containerUUID}/umbrelladnsrules                                                   |
| getUmbrellaDNSRule                             | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/umbrelladnspolicies/{containerUUID}/umbrelladnsrules/{objectId}                                        |
| updateUmbrellaDNSRule                          | PUT    | /api/fmc_config/v1/domain/{domainUUID}/policy/umbrelladnspolicies/{containerUUID}/umbrelladnsrules/{objectId}                                        |
| getUmbrellaDNSPolicy                           | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/umbrelladnspolicies/{objectId}                                                                         |
| updateUmbrellaDNSPolicy                        | PUT    | /api/fmc_config/v1/domain/{domainUUID}/policy/umbrelladnspolicies/{objectId}                                                                         |
| deleteUmbrellaDNSPolicy                        | DELETE | /api/fmc_config/v1/domain/{domainUUID}/policy/umbrelladnspolicies/{objectId}                                                                         |
| getAllVpnTunnelStatusModel                     | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/vpntunnelstatuses                                                                                      |
| getAllZeroTrustPolicy                          | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/zerotrustpolicies                                                                                      |
| createZeroTrustPolicy                          | POST   | /api/fmc_config/v1/domain/{domainUUID}/policy/zerotrustpolicies                                                                                      |
| getAllZeroTrustApplicationGroup                | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/zerotrustpolicies/{containerUUID}/applicationgroups                                                    |
| createZeroTrustApplicationGroup                | POST   | /api/fmc_config/v1/domain/{domainUUID}/policy/zerotrustpolicies/{containerUUID}/applicationgroups                                                    |
| getZeroTrustApplicationGroup                   | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/zerotrustpolicies/{containerUUID}/applicationgroups/{objectId}                                         |
| updateZeroTrustApplicationGroup                | PUT    | /api/fmc_config/v1/domain/{domainUUID}/policy/zerotrustpolicies/{containerUUID}/applicationgroups/{objectId}                                         |
| deleteZeroTrustApplicationGroup                | DELETE | /api/fmc_config/v1/domain/{domainUUID}/policy/zerotrustpolicies/{containerUUID}/applicationgroups/{objectId}                                         |
| getAllZeroTrustApplication                     | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/zerotrustpolicies/{containerUUID}/applications                                                         |
| createZeroTrustApplication                     | POST   | /api/fmc_config/v1/domain/{domainUUID}/policy/zerotrustpolicies/{containerUUID}/applications                                                         |
| updateMultipleZeroTrustApplication             | PUT    | /api/fmc_config/v1/domain/{domainUUID}/policy/zerotrustpolicies/{containerUUID}/applications                                                         |
| deleteMultipleZeroTrustApplication             | DELETE | /api/fmc_config/v1/domain/{domainUUID}/policy/zerotrustpolicies/{containerUUID}/applications                                                         |
| getZeroTrustApplication                        | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/zerotrustpolicies/{containerUUID}/applications/{objectId}                                              |
| updateZeroTrustApplication                     | PUT    | /api/fmc_config/v1/domain/{domainUUID}/policy/zerotrustpolicies/{containerUUID}/applications/{objectId}                                              |
| deleteZeroTrustApplication                     | DELETE | /api/fmc_config/v1/domain/{domainUUID}/policy/zerotrustpolicies/{containerUUID}/applications/{objectId}                                              |
| getZeroTrustPolicy                             | GET    | /api/fmc_config/v1/domain/{domainUUID}/policy/zerotrustpolicies/{objectId}                                                                           |
| updateZeroTrustPolicy                          | PUT    | /api/fmc_config/v1/domain/{domainUUID}/policy/zerotrustpolicies/{objectId}                                                                           |
| deleteZeroTrustPolicy                          | DELETE | /api/fmc_config/v1/domain/{domainUUID}/policy/zerotrustpolicies/{objectId}                                                                           |
| getGlobalDeviceSearch                          | GET    | /api/fmc_config/v1/domain/{domainUUID}/search/device                                                                                                 |
| getGlobalSearch                                | GET    | /api/fmc_config/v1/domain/{domainUUID}/search/global                                                                                                 |
| getGlobalObjectSearch                          | GET    | /api/fmc_config/v1/domain/{domainUUID}/search/object                                                                                                 |
| getGlobalPolicySearch                          | GET    | /api/fmc_config/v1/domain/{domainUUID}/search/policy                                                                                                 |
| getAllDeviceTemplates                          | GET    | /api/fmc_config/v1/domain/{domainUUID}/templates/devicetemplates                                                                                     |
| createDeviceTemplates                          | POST   | /api/fmc_config/v1/domain/{domainUUID}/templates/devicetemplates                                                                                     |
| createDeviceTemplateConversionRequestModel     | POST   | /api/fmc_config/v1/domain/{domainUUID}/templates/devicetemplates/operational/generatetemplate                                                        |
| getDeviceTemplates                             | GET    | /api/fmc_config/v1/domain/{domainUUID}/templates/devicetemplates/{containerUUID}                                                                     |
| updateDeviceTemplates                          | PUT    | /api/fmc_config/v1/domain/{domainUUID}/templates/devicetemplates/{containerUUID}                                                                     |
| deleteDeviceTemplates                          | DELETE | /api/fmc_config/v1/domain/{domainUUID}/templates/devicetemplates/{containerUUID}                                                                     |
| getDeviceTemplateAssociation                   | GET    | /api/fmc_config/v1/domain/{domainUUID}/templates/devicetemplates/{containerUUID}/associations                                                        |
| deleteDeviceTemplateAssociation                | DELETE | /api/fmc_config/v1/domain/{domainUUID}/templates/devicetemplates/{containerUUID}/associations/{objectId}                                             |
| getDeviceTemplateDefaultModelMapping           | GET    | /api/fmc_config/v1/domain/{domainUUID}/templates/devicetemplates/{containerUUID}/defaultmodelmappings/{modelName}                                    |
| getAllDeviceTemplateModelMapping               | GET    | /api/fmc_config/v1/domain/{domainUUID}/templates/devicetemplates/{containerUUID}/modelmappings                                                       |
| createDeviceTemplateModelMapping               | POST   | /api/fmc_config/v1/domain/{domainUUID}/templates/devicetemplates/{containerUUID}/modelmappings                                                       |
| getDeviceTemplateModelMapping                  | GET    | /api/fmc_config/v1/domain/{domainUUID}/templates/devicetemplates/{containerUUID}/modelmappings/{objectId}                                            |
| updateDeviceTemplateModelMapping               | PUT    | /api/fmc_config/v1/domain/{domainUUID}/templates/devicetemplates/{containerUUID}/modelmappings/{objectId}                                            |
| deleteDeviceTemplateModelMapping               | DELETE | /api/fmc_config/v1/domain/{domainUUID}/templates/devicetemplates/{containerUUID}/modelmappings/{objectId}                                            |
| getDeviceTemplateObjectOverrides               | GET    | /api/fmc_config/v1/domain/{domainUUID}/templates/devicetemplates/{containerUUID}/objectoverrides/{containerUUID}                                     |
| updateDeviceTemplateObjectOverrides            | PUT    | /api/fmc_config/v1/domain/{domainUUID}/templates/devicetemplates/{containerUUID}/objectoverrides/{containerUUID}                                     |
| createDeviceTemplateApply                      | POST   | /api/fmc_config/v1/domain/{domainUUID}/templates/devicetemplates/{containerUUID}/operational/apply                                                   |
| getAllFTDTemplatePhysicalInterface             | GET    | /api/fmc_config/v1/domain/{domainUUID}/templates/devicetemplates/{containerUUID}/templateinterfaces                                                  |
| createFTDTemplatePhysicalInterface             | POST   | /api/fmc_config/v1/domain/{domainUUID}/templates/devicetemplates/{containerUUID}/templateinterfaces                                                  |
| getFTDTemplatePhysicalInterface                | GET    | /api/fmc_config/v1/domain/{domainUUID}/templates/devicetemplates/{containerUUID}/templateinterfaces/{objectId}                                       |
| deleteFTDTemplatePhysicalInterface             | DELETE | /api/fmc_config/v1/domain/{domainUUID}/templates/devicetemplates/{containerUUID}/templateinterfaces/{objectId}                                       |
| getDeviceTemplateVariables                     | GET    | /api/fmc_config/v1/domain/{domainUUID}/templates/devicetemplates/{containerUUID}/variables                                                           |
| getAllVpnSettingModel                          | GET    | /api/fmc_config/v1/domain/{domainUUID}/templates/devicetemplates/{containerUUID}/vpnsettings                                                         |
| createVpnSettingModel                          | POST   | /api/fmc_config/v1/domain/{domainUUID}/templates/devicetemplates/{containerUUID}/vpnsettings                                                         |
| getVpnSettingModel                             | GET    | /api/fmc_config/v1/domain/{domainUUID}/templates/devicetemplates/{containerUUID}/vpnsettings/{objectId}                                              |
| updateVpnSettingModel                          | PUT    | /api/fmc_config/v1/domain/{domainUUID}/templates/devicetemplates/{containerUUID}/vpnsettings/{objectId}                                              |
| deleteVpnSettingModel                          | DELETE | /api/fmc_config/v1/domain/{domainUUID}/templates/devicetemplates/{containerUUID}/vpnsettings/{objectId}                                              |
| getAllSupportedDeviceModel                     | GET    | /api/fmc_config/v1/domain/{domainUUID}/templates/supporteddevicemodels                                                                               |
| getSupportedDeviceModel                        | GET    | /api/fmc_config/v1/domain/{domainUUID}/templates/supporteddevicemodels/{modelId}                                                                     |
| getAllAuthRoles                                | GET    | /api/fmc_config/v1/domain/{domainUUID}/users/authroles                                                                                               |
| getAllDuoConfig                                | GET    | /api/fmc_config/v1/domain/{domainUUID}/users/duoconfigs                                                                                              |
| getDuoConfig                                   | GET    | /api/fmc_config/v1/domain/{domainUUID}/users/duoconfigs/{objectId}                                                                                   |
| updateDuoConfig                                | PUT    | /api/fmc_config/v1/domain/{domainUUID}/users/duoconfigs/{objectId}                                                                                   |
| getAllSSOConfig                                | GET    | /api/fmc_config/v1/domain/{domainUUID}/users/ssoconfigs                                                                                              |
| getSSOConfig                                   | GET    | /api/fmc_config/v1/domain/{domainUUID}/users/ssoconfigs/{objectId}                                                                                   |
| updateSSOConfig                                | PUT    | /api/fmc_config/v1/domain/{domainUUID}/users/ssoconfigs/{objectId}                                                                                   |
| getAllFMCUser                                  | GET    | /api/fmc_config/v1/domain/{domainUUID}/users/users                                                                                                   |
| getFMCUser                                     | GET    | /api/fmc_config/v1/domain/{domainUUID}/users/users/{objectId}                                                                                        |
| getAllNetmapHost                               | GET    | /api/fmc_netmap/v1/domain/{domainUUID}/hosts                                                                                                         |
| createMultipleNetmapHost                       | POST   | /api/fmc_netmap/v1/domain/{domainUUID}/hosts                                                                                                         |
| deleteMultipleNetmapHost                       | DELETE | /api/fmc_netmap/v1/domain/{domainUUID}/hosts                                                                                                         |
| getNetmapHost                                  | GET    | /api/fmc_netmap/v1/domain/{domainUUID}/hosts/{objectId}                                                                                              |
| deleteNetmapHost                               | DELETE | /api/fmc_netmap/v1/domain/{domainUUID}/hosts/{objectId}                                                                                              |
| getAllNetmapVuln                               | GET    | /api/fmc_netmap/v1/domain/{domainUUID}/vulns                                                                                                         |
| createMultipleNetmapVuln                       | POST   | /api/fmc_netmap/v1/domain/{domainUUID}/vulns                                                                                                         |
| deleteMultipleNetmapVuln                       | DELETE | /api/fmc_netmap/v1/domain/{domainUUID}/vulns                                                                                                         |
| getNetmapVuln                                  | GET    | /api/fmc_netmap/v1/domain/{domainUUID}/vulns/{objectId}                                                                                              |
| deleteNetmapVuln                               | DELETE | /api/fmc_netmap/v1/domain/{domainUUID}/vulns/{objectId}                                                                                              |
| getAllAuditModel                               | GET    | /api/fmc_platform/v1/domain/{domainUUID}/audit/auditrecords                                                                                          |
| getAuditModel                                  | GET    | /api/fmc_platform/v1/domain/{domainUUID}/audit/auditrecords/{objectId}                                                                               |
| getAuditConfigChanges                          | GET    | /api/fmc_platform/v1/domain/{domainUUID}/audit/configchanges                                                                                         |
| getAllDomain                                   | GET    | /api/fmc_platform/v1/info/domain                                                                                                                     |
| getDomain                                      | GET    | /api/fmc_platform/v1/info/domain/{domainUUID}/{objectId}                                                                                             |
| getAllServerVersion                            | GET    | /api/fmc_platform/v1/info/serverversion                                                                                                              |
| getServerVersion                               | GET    | /api/fmc_platform/v1/info/serverversion/{objectId}                                                                                                   |
| getAllDeviceLicense                            | GET    | /api/fmc_platform/v1/license/devicelicenses                                                                                                          |
| updateMultipleDeviceLicense                    | PUT    | /api/fmc_platform/v1/license/devicelicenses                                                                                                          |
| getDeviceLicense                               | GET    | /api/fmc_platform/v1/license/devicelicenses/{objectId}                                                                                               |
| updateDeviceLicense                            | PUT    | /api/fmc_platform/v1/license/devicelicenses/{objectId}                                                                                               |
| getSmartLicense                                | GET    | /api/fmc_platform/v1/license/smartlicenses                                                                                                           |
| createSmartLicense                             | POST   | /api/fmc_platform/v1/license/smartlicenses                                                                                                           |
| getAllChangeManagementSystemConfig             | GET    | /api/fmc_platform/v1/systemconfiguration/changemanagementconfigs                                                                                     |
| getChangeManagementSystemConfig                | GET    | /api/fmc_platform/v1/systemconfiguration/changemanagementconfigs/{objectId}                                                                          |
| updateChangeManagementSystemConfig             | PUT    | /api/fmc_platform/v1/systemconfiguration/changemanagementconfigs/{objectId}                                                                          |
| getAllRemoteManagementAccess                   | GET    | /api/fmc_platform/v1/systemconfiguration/remotemanagementaccess                                                                                      |
| getRemoteManagementAccess                      | GET    | /api/fmc_platform/v1/systemconfiguration/remotemanagementaccess/{objectId}                                                                           |
| updateRemoteManagementAccess                   | PUT    | /api/fmc_platform/v1/systemconfiguration/remotemanagementaccess/{objectId}                                                                           |
| createCancelUpgrade                            | POST   | /api/fmc_platform/v1/updates/cancelupgrades                                                                                                          |
| createCustomUpgrade                            | POST   | /api/fmc_platform/v1/updates/customupgrade                                                                                                           |
| createRetryUpgrade                             | POST   | /api/fmc_platform/v1/updates/retryupgrades                                                                                                           |
| createRevertUpgrade                            | POST   | /api/fmc_platform/v1/updates/revertupgrades                                                                                                          |
| getAllUpgradePackage                           | GET    | /api/fmc_platform/v1/updates/upgradepackages                                                                                                         |
| getAllApplicableDevice                         | GET    | /api/fmc_platform/v1/updates/upgradepackages/{containerUUID}/applicabledevices                                                                       |
| getUpgradePackage                              | GET    | /api/fmc_platform/v1/updates/upgradepackages/{objectId}                                                                                              |
| deleteUpgradePackage                           | DELETE | /api/fmc_platform/v1/updates/upgradepackages/{objectId}                                                                                              |
| createUpgrade                                  | POST   | /api/fmc_platform/v1/updates/upgrades                                                                                                                |
| createUpgradeSnapshot                          | POST   | /api/fmc_platform/v1/updates/upgradesnapshot                                                                                                         |
| createRESTTaxiiCollection                      | POST   | /api/fmc_tid/v1/domain/{domainUUID}/taxiiconfig/collections                                                                                          |
| createRESTDiscoveryInfo                        | POST   | /api/fmc_tid/v1/domain/{domainUUID}/taxiiconfig/discoveryinfo                                                                                        |
| getAllRESTElement                              | GET    | /api/fmc_tid/v1/domain/{domainUUID}/tid/element                                                                                                      |
| getRESTElement                                 | GET    | /api/fmc_tid/v1/domain/{domainUUID}/tid/element/{objectId}                                                                                           |
| getAllRESTIncident                             | GET    | /api/fmc_tid/v1/domain/{domainUUID}/tid/incident                                                                                                     |
| getRESTIncident                                | GET    | /api/fmc_tid/v1/domain/{domainUUID}/tid/incident/{objectId}                                                                                          |
| updateRESTIncident                             | PUT    | /api/fmc_tid/v1/domain/{domainUUID}/tid/incident/{objectId}                                                                                          |
| deleteRESTIncident                             | DELETE | /api/fmc_tid/v1/domain/{domainUUID}/tid/incident/{objectId}                                                                                          |
| getAllRESTIndicator                            | GET    | /api/fmc_tid/v1/domain/{domainUUID}/tid/indicator                                                                                                    |
| getRESTIndicator                               | GET    | /api/fmc_tid/v1/domain/{domainUUID}/tid/indicator/{objectId}                                                                                         |
| updateRESTIndicator                            | PUT    | /api/fmc_tid/v1/domain/{domainUUID}/tid/indicator/{objectId}                                                                                         |
| getAllRESTObservable                           | GET    | /api/fmc_tid/v1/domain/{domainUUID}/tid/observable                                                                                                   |
| getRESTObservable                              | GET    | /api/fmc_tid/v1/domain/{domainUUID}/tid/observable/{objectId}                                                                                        |
| updateRESTObservable                           | PUT    | /api/fmc_tid/v1/domain/{domainUUID}/tid/observable/{objectId}                                                                                        |
| getRESTSettings                                | GET    | /api/fmc_tid/v1/domain/{domainUUID}/tid/settings/{objectId}                                                                                          |
| updateRESTSettings                             | PUT    | /api/fmc_tid/v1/domain/{domainUUID}/tid/settings/{objectId}                                                                                          |
| getAllRESTTidSource                            | GET    | /api/fmc_tid/v1/domain/{domainUUID}/tid/source                                                                                                       |
| createRESTTidSource                            | POST   | /api/fmc_tid/v1/domain/{domainUUID}/tid/source                                                                                                       |
| getRESTTidSource                               | GET    | /api/fmc_tid/v1/domain/{domainUUID}/tid/source/{objectId}                                                                                            |
| updateRESTTidSource                            | PUT    | /api/fmc_tid/v1/domain/{domainUUID}/tid/source/{objectId}                                                                                            |
| deleteRESTTidSource                            | DELETE | /api/fmc_tid/v1/domain/{domainUUID}/tid/source/{objectId}                                                                                            |
| getAllCPUProfiler                              | GET    | /api/fmc_troubleshoot/v1/domain/{domainUUID}/cpuprofiler/{containerUUID}/modules                                                                     |
| createCPUProfiler                              | POST   | /api/fmc_troubleshoot/v1/domain/{domainUUID}/cpuprofiler/{containerUUID}/modules                                                                     |
| getCPUProfiler                                 | GET    | /api/fmc_troubleshoot/v1/domain/{domainUUID}/cpuprofiler/{containerUUID}/modules/{profilerFileName}                                                  |
| createDeviceTroubleshoot                       | POST   | /api/fmc_troubleshoot/v1/domain/{domainUUID}/device                                                                                                  |
| getAllPacketTracerPCAPFiles                    | GET    | /api/fmc_troubleshoot/v1/domain/{domainUUID}/packettracer/files                                                                                      |
| createPacketTracerPCAPFiles                    | POST   | /api/fmc_troubleshoot/v1/domain/{domainUUID}/packettracer/files                                                                                      |
| deleteMultiplePacketTracerPCAPFiles            | DELETE | /api/fmc_troubleshoot/v1/domain/{domainUUID}/packettracer/files                                                                                      |
| getPacketTracerPCAPFiles                       | GET    | /api/fmc_troubleshoot/v1/domain/{domainUUID}/packettracer/files/{pcapFileName}                                                                       |
| deletePacketTracerPCAPFiles                    | DELETE | /api/fmc_troubleshoot/v1/domain/{domainUUID}/packettracer/files/{pcapFileName}                                                                       |
| getPacketTracerPCAPExtract                     | GET    | /api/fmc_troubleshoot/v1/domain/{domainUUID}/packettracer/files/{pcapFileName}/details                                                               |
| createPacketTracerPCAP                         | POST   | /api/fmc_troubleshoot/v1/domain/{domainUUID}/packettracer/pcaptraces                                                                                 |
| createPacketTracer                             | POST   | /api/fmc_troubleshoot/v1/domain/{domainUUID}/packettracer/traces                                                                                     |
| getAllSnortProfiler                            | GET    | /api/fmc_troubleshoot/v1/domain/{domainUUID}/snortprofiler/{containerUUID}/rules                                                                     |
| createSnortProfiler                            | POST   | /api/fmc_troubleshoot/v1/domain/{domainUUID}/snortprofiler/{containerUUID}/rules                                                                     |
| getSnortProfiler                               | GET    | /api/fmc_troubleshoot/v1/domain/{domainUUID}/snortprofiler/{containerUUID}/rules/{profilerFileName}                                                  |
| createTroubleshoot                             | POST   | /api/fmc_troubleshoot/v1/domain/{domainUUID}/task                                                                                                    |
